{
 "metadata": {
  "name": "",
  "signature": "sha256:28a369e49d26e217eef1b240f961a560ae6596703e8e5d21ae09edf7aeeb93a7"
 },
 "nbformat": 3,
 "nbformat_minor": 0,
 "worksheets": [
  {
   "cells": [
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "It's easy to record tracks (for instance while running) using the \"My tracks\" app on android systems. What about being able to re-use them?\n",
      "\n",
      "In :doc:`2014-11-22-reading-kml-my-tracks-files-in-ipython` we reviewed different approches. Let's now try to use this data.\n",
      "\n",
      "<!-- TEASER_END -->"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "%matplotlib inline\n",
      "import matplotlib.pyplot as plt\n",
      "import numpy as np"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 1
    },
    {
     "cell_type": "heading",
     "level": 2,
     "metadata": {},
     "source": [
      "the xmltodict solution"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "https://github.com/martinblech/xmltodict"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "class KmlReader():\n",
      "    def __init__(self, filename):\n",
      "        import pandas as pd\n",
      "        import xmltodict\n",
      "        with open(filename) as f:\n",
      "            kml_dict = xmltodict.parse(f)\n",
      "        doc = kml_dict['kml']['Document']\n",
      "        keypoint_folder = doc['Folder']\n",
      "        Placemark = doc['Placemark']\n",
      "        self.tracks_type =  Placemark[1]['ExtendedData']['Data']['value']\n",
      "        track = Placemark[1]['gx:MultiTrack']['gx:Track']\n",
      "        self.lon, self.lat, self.alt = [], [], []\n",
      "        for when, where in zip(track['when'], track['gx:coord']):\n",
      "            self.whens = pd.to_datetime(track['when'])\n",
      "            for coord in track['gx:coord']:\n",
      "                lon, lat, alt = coord.split(' ')\n",
      "                self.lon.append(np.float(lon))\n",
      "                self.lat.append(np.float(lat))\n",
      "                self.alt.append(np.float(alt))\n",
      "\n",
      "filename = '/tmp/test.kml'\n",
      "track =  KmlReader(filename)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 2
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "http://nbviewer.ipython.org/urls/bitbucket.org/hrojas/learn-pandas/raw/master/lessons/01%20-%20Lesson.ipynb"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "import pandas as pd\n",
      "whens = pd.to_datetime(track.whens)\n",
      "print whens[0], whens[0].ctime()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "2013-04-27 12:33:51 Sat Apr 27 12:33:51 2013\n"
       ]
      }
     ],
     "prompt_number": 3
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "df = pd.DataFrame(data = zip(track.whens, track.lon, track.lat, track.alt), columns=['time', 'lon', 'lat', 'alt'])"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 4
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "df"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "<div style=\"max-height:1000px;max-width:1500px;overflow:auto;\">\n",
        "<table border=\"1\" class=\"dataframe\">\n",
        "  <thead>\n",
        "    <tr style=\"text-align: right;\">\n",
        "      <th></th>\n",
        "      <th>time</th>\n",
        "      <th>lon</th>\n",
        "      <th>lat</th>\n",
        "      <th>alt</th>\n",
        "    </tr>\n",
        "  </thead>\n",
        "  <tbody>\n",
        "    <tr>\n",
        "      <th>0   </th>\n",
        "      <td>       2013-04-27 12:33:51</td>\n",
        "      <td> 5.393242</td>\n",
        "      <td> 43.262411</td>\n",
        "      <td> 73.477097</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>1   </th>\n",
        "      <td>       2013-04-27 12:33:55</td>\n",
        "      <td> 5.393219</td>\n",
        "      <td> 43.262444</td>\n",
        "      <td> 72.936981</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2   </th>\n",
        "      <td>       2013-04-27 12:33:56</td>\n",
        "      <td> 5.393213</td>\n",
        "      <td> 43.262457</td>\n",
        "      <td> 73.197395</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>3   </th>\n",
        "      <td>       2013-04-27 12:33:58</td>\n",
        "      <td> 5.393202</td>\n",
        "      <td> 43.262490</td>\n",
        "      <td> 65.184090</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>4   </th>\n",
        "      <td>       2013-04-27 12:33:59</td>\n",
        "      <td> 5.393198</td>\n",
        "      <td> 43.262511</td>\n",
        "      <td> 65.366005</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>5   </th>\n",
        "      <td>       2013-04-27 12:34:00</td>\n",
        "      <td> 5.393193</td>\n",
        "      <td> 43.262535</td>\n",
        "      <td> 61.444321</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>6   </th>\n",
        "      <td>       2013-04-27 12:34:01</td>\n",
        "      <td> 5.393187</td>\n",
        "      <td> 43.262560</td>\n",
        "      <td> 61.353985</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>7   </th>\n",
        "      <td>       2013-04-27 12:34:02</td>\n",
        "      <td> 5.393182</td>\n",
        "      <td> 43.262588</td>\n",
        "      <td> 61.959949</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>8   </th>\n",
        "      <td>       2013-04-27 12:34:03</td>\n",
        "      <td> 5.393178</td>\n",
        "      <td> 43.262616</td>\n",
        "      <td> 63.015228</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>9   </th>\n",
        "      <td>       2013-04-27 12:34:04</td>\n",
        "      <td> 5.393176</td>\n",
        "      <td> 43.262642</td>\n",
        "      <td> 64.982201</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>10  </th>\n",
        "      <td>       2013-04-27 12:34:05</td>\n",
        "      <td> 5.393172</td>\n",
        "      <td> 43.262666</td>\n",
        "      <td> 67.654190</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>11  </th>\n",
        "      <td>       2013-04-27 12:34:06</td>\n",
        "      <td> 5.393163</td>\n",
        "      <td> 43.262696</td>\n",
        "      <td> 69.057785</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>12  </th>\n",
        "      <td>       2013-04-27 12:34:07</td>\n",
        "      <td> 5.393154</td>\n",
        "      <td> 43.262726</td>\n",
        "      <td> 70.457108</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>13  </th>\n",
        "      <td>       2013-04-27 12:34:08</td>\n",
        "      <td> 5.393145</td>\n",
        "      <td> 43.262758</td>\n",
        "      <td> 71.321938</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>14  </th>\n",
        "      <td>       2013-04-27 12:34:09</td>\n",
        "      <td> 5.393138</td>\n",
        "      <td> 43.262785</td>\n",
        "      <td> 71.303345</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>15  </th>\n",
        "      <td>       2013-04-27 12:34:10</td>\n",
        "      <td> 5.393130</td>\n",
        "      <td> 43.262811</td>\n",
        "      <td> 70.360481</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>16  </th>\n",
        "      <td>       2013-04-27 12:34:11</td>\n",
        "      <td> 5.393121</td>\n",
        "      <td> 43.262837</td>\n",
        "      <td> 70.317429</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>17  </th>\n",
        "      <td>       2013-04-27 12:34:12</td>\n",
        "      <td> 5.393112</td>\n",
        "      <td> 43.262863</td>\n",
        "      <td> 70.237083</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>18  </th>\n",
        "      <td>       2013-04-27 12:34:13</td>\n",
        "      <td> 5.393102</td>\n",
        "      <td> 43.262893</td>\n",
        "      <td> 70.133751</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>19  </th>\n",
        "      <td>       2013-04-27 12:34:14</td>\n",
        "      <td> 5.393094</td>\n",
        "      <td> 43.262922</td>\n",
        "      <td> 70.093513</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>20  </th>\n",
        "      <td>       2013-04-27 12:34:15</td>\n",
        "      <td> 5.393084</td>\n",
        "      <td> 43.262948</td>\n",
        "      <td> 70.045280</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>21  </th>\n",
        "      <td>       2013-04-27 12:34:16</td>\n",
        "      <td> 5.393066</td>\n",
        "      <td> 43.262980</td>\n",
        "      <td> 69.968422</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>22  </th>\n",
        "      <td>       2013-04-27 12:34:17</td>\n",
        "      <td> 5.393051</td>\n",
        "      <td> 43.263008</td>\n",
        "      <td> 69.871803</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>23  </th>\n",
        "      <td>       2013-04-27 12:34:18</td>\n",
        "      <td> 5.393032</td>\n",
        "      <td> 43.263037</td>\n",
        "      <td> 69.833954</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>24  </th>\n",
        "      <td>       2013-04-27 12:34:19</td>\n",
        "      <td> 5.393016</td>\n",
        "      <td> 43.263068</td>\n",
        "      <td> 69.833076</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>25  </th>\n",
        "      <td>       2013-04-27 12:34:20</td>\n",
        "      <td> 5.392996</td>\n",
        "      <td> 43.263098</td>\n",
        "      <td> 69.859688</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>26  </th>\n",
        "      <td>       2013-04-27 12:34:21</td>\n",
        "      <td> 5.392975</td>\n",
        "      <td> 43.263126</td>\n",
        "      <td> 69.856659</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>27  </th>\n",
        "      <td>       2013-04-27 12:34:22</td>\n",
        "      <td> 5.392955</td>\n",
        "      <td> 43.263158</td>\n",
        "      <td> 69.842468</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>28  </th>\n",
        "      <td>       2013-04-27 12:34:23</td>\n",
        "      <td> 5.392938</td>\n",
        "      <td> 43.263187</td>\n",
        "      <td> 69.828461</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>29  </th>\n",
        "      <td>       2013-04-27 12:34:24</td>\n",
        "      <td> 5.392922</td>\n",
        "      <td> 43.263216</td>\n",
        "      <td> 69.836105</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>...</th>\n",
        "      <td>...</td>\n",
        "      <td>...</td>\n",
        "      <td>...</td>\n",
        "      <td>...</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2397</th>\n",
        "      <td>2013-04-27 13:19:25.999000</td>\n",
        "      <td> 5.393512</td>\n",
        "      <td> 43.261531</td>\n",
        "      <td> 67.265388</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2398</th>\n",
        "      <td>2013-04-27 13:19:26.999000</td>\n",
        "      <td> 5.393520</td>\n",
        "      <td> 43.261507</td>\n",
        "      <td> 67.271210</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2399</th>\n",
        "      <td>2013-04-27 13:19:27.999000</td>\n",
        "      <td> 5.393536</td>\n",
        "      <td> 43.261481</td>\n",
        "      <td> 67.263725</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2400</th>\n",
        "      <td>2013-04-27 13:19:29.999000</td>\n",
        "      <td> 5.393595</td>\n",
        "      <td> 43.261480</td>\n",
        "      <td> 67.192612</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2401</th>\n",
        "      <td>2013-04-27 13:19:30.999000</td>\n",
        "      <td> 5.393635</td>\n",
        "      <td> 43.261495</td>\n",
        "      <td> 67.161255</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2402</th>\n",
        "      <td>2013-04-27 13:19:31.999000</td>\n",
        "      <td> 5.393691</td>\n",
        "      <td> 43.261518</td>\n",
        "      <td> 67.093140</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2403</th>\n",
        "      <td>2013-04-27 13:19:32.999000</td>\n",
        "      <td> 5.393748</td>\n",
        "      <td> 43.261535</td>\n",
        "      <td> 67.003372</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2404</th>\n",
        "      <td>2013-04-27 13:19:33.999000</td>\n",
        "      <td> 5.393785</td>\n",
        "      <td> 43.261550</td>\n",
        "      <td> 66.965759</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2405</th>\n",
        "      <td>2013-04-27 13:19:34.999000</td>\n",
        "      <td> 5.393821</td>\n",
        "      <td> 43.261566</td>\n",
        "      <td> 66.941238</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2406</th>\n",
        "      <td>2013-04-27 13:19:36.999000</td>\n",
        "      <td> 5.393871</td>\n",
        "      <td> 43.261590</td>\n",
        "      <td> 66.851234</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2407</th>\n",
        "      <td>2013-04-27 13:19:37.999000</td>\n",
        "      <td> 5.393886</td>\n",
        "      <td> 43.261600</td>\n",
        "      <td> 66.808517</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2408</th>\n",
        "      <td>2013-04-27 13:19:39.999000</td>\n",
        "      <td> 5.393918</td>\n",
        "      <td> 43.261618</td>\n",
        "      <td> 66.744225</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2409</th>\n",
        "      <td>2013-04-27 13:19:40.999000</td>\n",
        "      <td> 5.393945</td>\n",
        "      <td> 43.261633</td>\n",
        "      <td> 66.713600</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2410</th>\n",
        "      <td>2013-04-27 13:19:41.999000</td>\n",
        "      <td> 5.393977</td>\n",
        "      <td> 43.261646</td>\n",
        "      <td> 66.665375</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2411</th>\n",
        "      <td>2013-04-27 13:19:42.999000</td>\n",
        "      <td> 5.394010</td>\n",
        "      <td> 43.261654</td>\n",
        "      <td> 66.593460</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2412</th>\n",
        "      <td>2013-04-27 13:19:43.999000</td>\n",
        "      <td> 5.394047</td>\n",
        "      <td> 43.261670</td>\n",
        "      <td> 66.497551</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2413</th>\n",
        "      <td>2013-04-27 13:19:44.999000</td>\n",
        "      <td> 5.394077</td>\n",
        "      <td> 43.261684</td>\n",
        "      <td> 66.413139</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2414</th>\n",
        "      <td>2013-04-27 13:19:46.999000</td>\n",
        "      <td> 5.394127</td>\n",
        "      <td> 43.261704</td>\n",
        "      <td> 66.249512</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2415</th>\n",
        "      <td>2013-04-27 13:19:47.999000</td>\n",
        "      <td> 5.394151</td>\n",
        "      <td> 43.261718</td>\n",
        "      <td> 66.162277</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2416</th>\n",
        "      <td>2013-04-27 13:19:48.999000</td>\n",
        "      <td> 5.394175</td>\n",
        "      <td> 43.261732</td>\n",
        "      <td> 66.049507</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2417</th>\n",
        "      <td>2013-04-27 13:19:49.999000</td>\n",
        "      <td> 5.394201</td>\n",
        "      <td> 43.261746</td>\n",
        "      <td> 65.929634</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2418</th>\n",
        "      <td>2013-04-27 13:19:51.999000</td>\n",
        "      <td> 5.394245</td>\n",
        "      <td> 43.261771</td>\n",
        "      <td> 65.717690</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2419</th>\n",
        "      <td>2013-04-27 13:19:52.999000</td>\n",
        "      <td> 5.394269</td>\n",
        "      <td> 43.261783</td>\n",
        "      <td> 65.646263</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2420</th>\n",
        "      <td>2013-04-27 13:19:54.999000</td>\n",
        "      <td> 5.394322</td>\n",
        "      <td> 43.261802</td>\n",
        "      <td> 65.457573</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2421</th>\n",
        "      <td>2013-04-27 13:19:55.999000</td>\n",
        "      <td> 5.394355</td>\n",
        "      <td> 43.261809</td>\n",
        "      <td> 65.409889</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2422</th>\n",
        "      <td>2013-04-27 13:19:57.999000</td>\n",
        "      <td> 5.394403</td>\n",
        "      <td> 43.261835</td>\n",
        "      <td> 65.301704</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2423</th>\n",
        "      <td>2013-04-27 13:19:58.999000</td>\n",
        "      <td> 5.394425</td>\n",
        "      <td> 43.261847</td>\n",
        "      <td> 65.255844</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2424</th>\n",
        "      <td>2013-04-27 13:20:00.999000</td>\n",
        "      <td> 5.394464</td>\n",
        "      <td> 43.261873</td>\n",
        "      <td> 65.148201</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2425</th>\n",
        "      <td>2013-04-27 13:20:01.999000</td>\n",
        "      <td> 5.394480</td>\n",
        "      <td> 43.261883</td>\n",
        "      <td> 65.100128</td>\n",
        "    </tr>\n",
        "    <tr>\n",
        "      <th>2426</th>\n",
        "      <td>2013-04-27 13:20:06.999000</td>\n",
        "      <td> 5.394510</td>\n",
        "      <td> 43.261919</td>\n",
        "      <td> 64.971428</td>\n",
        "    </tr>\n",
        "  </tbody>\n",
        "</table>\n",
        "<p>2427 rows \u00d7 4 columns</p>\n",
        "</div>"
       ],
       "metadata": {},
       "output_type": "pyout",
       "prompt_number": 5,
       "text": [
        "                           time       lon        lat        alt\n",
        "0           2013-04-27 12:33:51  5.393242  43.262411  73.477097\n",
        "1           2013-04-27 12:33:55  5.393219  43.262444  72.936981\n",
        "2           2013-04-27 12:33:56  5.393213  43.262457  73.197395\n",
        "3           2013-04-27 12:33:58  5.393202  43.262490  65.184090\n",
        "4           2013-04-27 12:33:59  5.393198  43.262511  65.366005\n",
        "5           2013-04-27 12:34:00  5.393193  43.262535  61.444321\n",
        "6           2013-04-27 12:34:01  5.393187  43.262560  61.353985\n",
        "7           2013-04-27 12:34:02  5.393182  43.262588  61.959949\n",
        "8           2013-04-27 12:34:03  5.393178  43.262616  63.015228\n",
        "9           2013-04-27 12:34:04  5.393176  43.262642  64.982201\n",
        "10          2013-04-27 12:34:05  5.393172  43.262666  67.654190\n",
        "11          2013-04-27 12:34:06  5.393163  43.262696  69.057785\n",
        "12          2013-04-27 12:34:07  5.393154  43.262726  70.457108\n",
        "13          2013-04-27 12:34:08  5.393145  43.262758  71.321938\n",
        "14          2013-04-27 12:34:09  5.393138  43.262785  71.303345\n",
        "15          2013-04-27 12:34:10  5.393130  43.262811  70.360481\n",
        "16          2013-04-27 12:34:11  5.393121  43.262837  70.317429\n",
        "17          2013-04-27 12:34:12  5.393112  43.262863  70.237083\n",
        "18          2013-04-27 12:34:13  5.393102  43.262893  70.133751\n",
        "19          2013-04-27 12:34:14  5.393094  43.262922  70.093513\n",
        "20          2013-04-27 12:34:15  5.393084  43.262948  70.045280\n",
        "21          2013-04-27 12:34:16  5.393066  43.262980  69.968422\n",
        "22          2013-04-27 12:34:17  5.393051  43.263008  69.871803\n",
        "23          2013-04-27 12:34:18  5.393032  43.263037  69.833954\n",
        "24          2013-04-27 12:34:19  5.393016  43.263068  69.833076\n",
        "25          2013-04-27 12:34:20  5.392996  43.263098  69.859688\n",
        "26          2013-04-27 12:34:21  5.392975  43.263126  69.856659\n",
        "27          2013-04-27 12:34:22  5.392955  43.263158  69.842468\n",
        "28          2013-04-27 12:34:23  5.392938  43.263187  69.828461\n",
        "29          2013-04-27 12:34:24  5.392922  43.263216  69.836105\n",
        "...                         ...       ...        ...        ...\n",
        "2397 2013-04-27 13:19:25.999000  5.393512  43.261531  67.265388\n",
        "2398 2013-04-27 13:19:26.999000  5.393520  43.261507  67.271210\n",
        "2399 2013-04-27 13:19:27.999000  5.393536  43.261481  67.263725\n",
        "2400 2013-04-27 13:19:29.999000  5.393595  43.261480  67.192612\n",
        "2401 2013-04-27 13:19:30.999000  5.393635  43.261495  67.161255\n",
        "2402 2013-04-27 13:19:31.999000  5.393691  43.261518  67.093140\n",
        "2403 2013-04-27 13:19:32.999000  5.393748  43.261535  67.003372\n",
        "2404 2013-04-27 13:19:33.999000  5.393785  43.261550  66.965759\n",
        "2405 2013-04-27 13:19:34.999000  5.393821  43.261566  66.941238\n",
        "2406 2013-04-27 13:19:36.999000  5.393871  43.261590  66.851234\n",
        "2407 2013-04-27 13:19:37.999000  5.393886  43.261600  66.808517\n",
        "2408 2013-04-27 13:19:39.999000  5.393918  43.261618  66.744225\n",
        "2409 2013-04-27 13:19:40.999000  5.393945  43.261633  66.713600\n",
        "2410 2013-04-27 13:19:41.999000  5.393977  43.261646  66.665375\n",
        "2411 2013-04-27 13:19:42.999000  5.394010  43.261654  66.593460\n",
        "2412 2013-04-27 13:19:43.999000  5.394047  43.261670  66.497551\n",
        "2413 2013-04-27 13:19:44.999000  5.394077  43.261684  66.413139\n",
        "2414 2013-04-27 13:19:46.999000  5.394127  43.261704  66.249512\n",
        "2415 2013-04-27 13:19:47.999000  5.394151  43.261718  66.162277\n",
        "2416 2013-04-27 13:19:48.999000  5.394175  43.261732  66.049507\n",
        "2417 2013-04-27 13:19:49.999000  5.394201  43.261746  65.929634\n",
        "2418 2013-04-27 13:19:51.999000  5.394245  43.261771  65.717690\n",
        "2419 2013-04-27 13:19:52.999000  5.394269  43.261783  65.646263\n",
        "2420 2013-04-27 13:19:54.999000  5.394322  43.261802  65.457573\n",
        "2421 2013-04-27 13:19:55.999000  5.394355  43.261809  65.409889\n",
        "2422 2013-04-27 13:19:57.999000  5.394403  43.261835  65.301704\n",
        "2423 2013-04-27 13:19:58.999000  5.394425  43.261847  65.255844\n",
        "2424 2013-04-27 13:20:00.999000  5.394464  43.261873  65.148201\n",
        "2425 2013-04-27 13:20:01.999000  5.394480  43.261883  65.100128\n",
        "2426 2013-04-27 13:20:06.999000  5.394510  43.261919  64.971428\n",
        "\n",
        "[2427 rows x 4 columns]"
       ]
      }
     ],
     "prompt_number": 5
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "df.info()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "<class 'pandas.core.frame.DataFrame'>\n",
        "Int64Index: 2427 entries, 0 to 2426\n",
        "Data columns (total 4 columns):\n",
        "time    2427 non-null datetime64[ns]\n",
        "lon     2427 non-null float64\n",
        "lat     2427 non-null float64\n",
        "alt     2427 non-null float64\n",
        "dtypes: datetime64[ns](1), float64(3)\n",
        "memory usage: 94.8 KB\n"
       ]
      }
     ],
     "prompt_number": 6
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Looks good... Can we plot that?"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "df['alt'].plot(figsize=(15,5));"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAA2QAAAE6CAYAAAB585FmAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nYII=\n",
       "text": [
        "<matplotlib.figure.Figure at 0x10d3d3c10>"
       ]
      }
     ],
     "prompt_number": 7
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Another way:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "df.plot(x='time', y='alt', figsize=(15,5), label='altitude', legend=False);"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAA2QAAAFFCAYAAACDhy5yAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n/wOe5Bi1RmzYlgAAAABJRU5ErkJggg==\n",
       "text": [
        "<matplotlib.figure.Figure at 0x10e3d68d0>"
       ]
      }
     ],
     "prompt_number": 8
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "df.plot(x='time', y='lon', figsize=(15,5), label='longitude')\n",
      "df.plot(x='time', y='lat', figsize=(15,5), label='lattitude', legend=False);"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAA3QAAAFFCAYAAACkKa+aAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz\nAAALEgAACxIB0t1+/AAAIABJREFUeJzs3Xl8VNX9//HXZAOyQEJISAIBQlgFZRUXEEFwoS6g1lOt\nu9a6VWsXrHbRalutW9Va6w/trq31uKCtirIpGheQghrZISyBkARC9j0z8/uDwS8iCQGSe2d5Px+P\nPMyduTP5zJtxZj5zz7nH4/f7ERERERERkdAT5XYBIiIiIiIicmTU0ImIiIiIiIQoNXQiIiIiIiIh\nSg2diIiIiIhIiFJDJyIiIiIiEqLU0ImIiIiIiISomEPtYIzZAlQBXqDZWjvhgOtnAvcCvsDPbGvt\n4sB13we+A3iAZ6y1j+93u1uAmwL3+4a19icd8YBEREREREQiRXuO0PmBKdbaMQc2cwELrbWjrLVj\ngKuApwGMMSPZ28wdD4wCzjHG5AaumwqcBxxnrR0JPHzUj0RERERERCTCtHfIpae1K6y1tfttJgK7\nA78PB5ZaaxustV5gCXBB4Lobgfuttc2B+9h1WFWLiIiIiIjIoYdcsvcI3UJjjBeYY6195sAdjDGz\ngPuBTOCMwMX5wK+NMT2BBuBsYFngusHAZGPMfYHrfmytXX5Uj0RERERERCTCtOcI3cTAcMoZwM3G\nmFMO3MFa+6q1djhwLvBs4LK1wAPAfGAesJK98+VgbyOZYq09EZgN2KN9ICIiIiIiIpHG4/f7272z\nMeZuoMZa+0gb+2wCJlhryw64/D5gm7X2/xlj5gG/tdYuCVy3ETjhwNvss2jRovYXKSIiIiIiEoam\nTZv2talwbQ65NMbEA9HW2mpjTAJ7h1Pec8A+uUCBtdZvjBkLsK8xM8akW2tLjTH9gPOBEwI3exU4\nDVhijBkCxLXWzO0zduzY9jxGERERERGRsLNixYqDXn6oOXS9gbnGmH37/tNaO98Ycz2AtXYOcCFw\nhTGmGagBLt7v9i8ZY1KBZuAma21V4PK/AH8xxuQDTcAVR/SoREREREREIthhDbl0y6JFi/zhfIQu\nLy+PSZMmuV1GRFDWzlDOzlHWzlDOzlHWzlDOzlHWzoiEnFesWHHQIZftXbZAREREREREgoyO0ImI\niIiIiAS51o7QtWcduqDl9/spLS3F6/UeeucIEx0dTXp6Oh5Pq2vCi4iIiIhIiAvphq60tJSkpCTi\n4+PdLiXo1NXVUVpaSu/evd0uJahEwvjqYKCcnaOsnaGcnaOsnaGcnaOsnRHJOYf0HDqv16tmrhXx\n8fE6cikiIiIiEuZCeg5dUVERWVlZLlQUGpSPiIiIiEh40FkuRUREREREwowaOokoeXl5bpcQEZSz\nc5S1M5Szc5S1M5Szc5S1MyI5ZzV0nWDUqFEMHTqUurq6Ly/7xz/+wXnnnediVSIiIiIiEm7U0HUS\nn8/HnDlz3C5DDhCpZz9ymnJ2jrJ2hnJ2jrJ2hnJ2jrJ2RiTnrIauE3g8Hr73ve/xhz/8gaqqqq9d\nv3TpUqZNm8aAAQOYPn06y5Yt+/K6c889l/vuu48ZM2bQr18/LrzwQvbs2fPl9Z988glnnnkmOTk5\nTJ48mQ8++MCRxyQiIiIiIsFHDV0nGT16NBMnTuSJJ574yuUVFRVcfPHF3HDDDRQUFHDjjTdy8cUX\nU1FR8eU+r7zyCk8++STr16+nubmZP/zhD8Des1ZecsklzJ49m82bN3Pvvfdy5ZVXUlZW5uhjC2WR\nPL7aScrZOcraGcrZOcraGcrZOcraGZGcc0gvLH4oZ/xpZYfcz/zvjDns23g8Hu68805mzJjBDTfc\n8H/3NX8+ubm5XHTRRQBceOGFPP3008ybN49LLrkEj8fDt7/9bQYOHAjArFmzmDdvHgAvvvgip59+\nOtOnTwdgypQpjB49mgULFnDxxRcf7cMUEREREZEQE9YN3ZE0Yh1p+PDhnHnmmTz22GMMGTIEgOLi\nYrKzs7+yX3Z2NsXFxV9up6enf/l7165dqa2tBaCwsJDXXnuNt95668vrvV4vkydP7syHEVYieXy1\nk5Szc5S1M5Szc5S1M5Szc5S1MyI557Bu6ILBHXfcwZQpU7j55psByMjIoLCw8Cv7FBYWfnnUrS19\n+/bFGMNjjz3WKbWKiIiIiEho0Ry6TpaTk8P555/PnDlz8Hg8nH766WzatImXX36ZlpYWXnnlFTZs\n2MCZZ5755W38fv9B7+uiiy7i7bffZvHixXi9XhoaGsjLy6OoqMiphxPyInl8tZOUs3OUtTOUs3OU\ntTOUs3OUtTPCPWdfK/0BqKFzxOzZs6mvrwcgJSWF559/nieffJJBgwbx5JNP8vzzz5OSkvLl/h6P\n5yu/79vu06cPzz33HI8++ihDhgzhuOOO48knn8Tn8zn7gEREREREpNN9VlTNPQsKuORfX7S6j6e1\no0HBZNGiRf6xY8d+7fKioiKysrJcqCg0KB8RERERkdD07qZynvp4O1ePz+KE7O5sXpvPtGnTPAfu\npzl0IiIiIiIiQeTznTU8+dF2HvzGIHJ6dgNgcyv7HrKhM8ZsAaoAL9BsrZ1wwPUzgXsBX+BntrV2\nceC67wPfATzAM9baxw+47Y+Ah4Be1to9iHSyvLy8iD4LklOUs3OUtTOUs3OUtTOUs3OUtTPCKefC\nigZ+vWgzd07t/2Uz15b2HKHzA1PaaLgWWmtfAzDGHAvMBQYZY0ayt5k7HmgG3jLGvG6t3RTYNxs4\nHdjajhpERERERETCWnl9Mz9/exPXHJ/F2D7d23Wb9p4U5WtjNfex1tbut5kI7A78PhxYaq1tsNZ6\ngSXABfvt+zvg9nb+fZEOES7f3AQ75ewcZe0M5ewcZe0M5ewcZe2McMi5scXH3fMLmJKbwllDU9t9\nu/YeoVtojPECc6y1zxy4gzFmFnA/kAmcEbg4H/i1MaYn0ACcDSwL7D8T2G6t/dwY0+5iRURERERE\nwtHjHxSS2b0LV43LPKzbtecI3URr7RhgBnCzMeaUA3ew1r5qrR0OnAs8G7hsLfAAMB+YB6wEvMaY\nbsBPgbv3u4tWjwC2JTo6mrq6uiO5adirq6sjOjra7TKCTrivURIslLNzlLUzlLNzlLUzlLNzlLUz\nQj3nj7dV8kVxDbdNyv7KEmbtcVjLFhhj7gZqrLWPtLHPJmCCtbbsgMvvA7YBecAiYF8n1hfYEbhN\n6cHuc9GiRf66urovD6Xu+webOHEipaWllJWV4fF46NGjBwCVlZUAIbNdVFREQkJCh91fRUUFjY2N\njB49Go/H82VeB+YXidv7/88eDPWE63Z+fj433nhj0NQTzttPPfUUxx57bNDUE67b+y4LlnrCeVuv\nH3o/DLftfZcFSz3huh3K74dbyuv54aurubBPI5eecXKr+8fHxx902YI2GzpjTDwQba2tNsYksPdo\n2z3W2vn77ZMLFFhr/caYscCL1trcwHXp1tpSY0w/4G3gBGtt1QF/YzMwrq2zXLa2Dp2IiIiIiEio\nWr+rjp+/vYnvntCH6YN7trnvihUrjmgdut7A3MA8txjgn9ba+caY6wGstXOAC4ErjDHNQA1w8X63\nf8kYk8res1zedGAzFxD8K5uLiIiIiIh0IK/Pz33vbOZ7E/syOSfliO/nsIZcuiXcj9Dl5YXPuhnB\nTlk7Qzk7R1k7Qzk7R1k7Qzk7R1k7IxRzfn9zBa98Ucqj5w5p1/6tHaFr77IFIiIiIiIi0gH8fj8v\n55cya0TaUd+XjtCJiIiIiIg46D+rd/H2+jJ+f95QoqPad1bLI51DJyIiIiIiIkfJ7/fzyfYqXvis\nlN21TdxzxsB2N3Nt0ZDLILD/aW2lcylrZyhn5yhrZyhn5yhrZyhn5yhrZ3RmzuX1zXy+s5o1pbXM\nX1/GP/63kx2VDV/br7HFR12Tl9ZGQM5dtYs/frSdbwxL5S8XHcOAlG4dUp+O0ImIiIiIiBygrLaZ\nN9bu5r9rdpORFIcH6JUQS1piHLf9dwNen5/kbjGkdIsFYP2uWgC6xETRvWsMSV2iSY2PJS0hjqKq\nRraUN/DgNwaR2b1Lh9apOXQiIiIiIiJAVUMLizeV8/b6Mkqqm5g8MJkLRqbTL7nrV/bz+f3UNHop\nr2+mvL6FFp+fkRmJxEV7qKhvoabRS3VjC2V1zZTWNJGaEMuE7B4kxEUfcW0hP4fuZ29t4rjMRIan\nxzM8PYHYaI0WFRERERGRI+P1+dm0p56y2mYK9tSzckc1G8vqmJDdnesmZDE6K4koz8HnuEV5PHTv\nGkP3rjH0P2AJuZ7xsfSMj3XgEQRqcewvHaUZQ1Mpq2vm6aVFXPnCal74rITqxha3y+oQGlvtHGXt\nDOXsHGXtDOXsHGXtDOXsHGXtjMPJucnr451N5dzwylp++84W3ly7m5rGFsyodJ7/9kh+eloOY/t0\nb7WZCzYhc4RuUk4yk3KSAdhUVsfL+aVcZVdz/og0Lhmd0SFniBERERERkfBU3+zlv6t382J+Kf2T\nu/LdE/owvm8SnhBp3FoT0nPoSmuaeGjJVrrGRPHT0wbQLfbIx6SKiIiIiEh4Wr+rjl8uLGBEegLf\nHpNBTs+OOcOkk1qbQxcyQy4PJj0xjvtnDCK5Www/en0Dq0pq8PqCv0EVERERERFn7Khs4BfzN3HT\nSX352bSckGzm2hLSDR1ATJSHH57Sj3OPSeOR97Zx4bOf85M3N/L6mt0h09xpbLVzlLUzlLNzlLUz\nlLNzlLUzlLNzlLUzDpazz++nsKKBn71dwJXjMpk0INmFyjpfyMyha4vH42HG0FRmDE2lsqGF1SW1\nvPh5Cf9aWUxOz26cPTyVE7J7aJ6diIiIiEgYa/H5eW7FThZtLKeyoYWkLtGcM7wX3xjWy+3SOk1I\nz6Fri9/vp7CykfW76vjP6l3UNnn56WkDyE2N76QqRURERETEDTsqGymqauT9zRWU1DRyw4l9SU+M\nO6p134JNyK9Dd7g8Hg/9krvSL7kr0wf3ZNHGPdwxbxNXjsvk7GGpIX82GxERERGRSNbi87N44x5e\nzi+lqtHLgJSuJHeL4efTckjqErZtzteE/By69po2qCePnDOYN9fu5teLt9DQ4nO7pC9pbLVzlLUz\nlLNzlLUzlLNzlLUzlLNzlHXH8/v9vL5mN1fZVSzauIfvntCHm7IruH/GIH4yZUBENXMQQQ0dQL/k\nrjx23hBiojzcPX8TTUHU1ImIiIiIyKE9t7KY19fs5uen5fDANwYzrm93InnwXdjOoWuL1+fngXe3\nUN/s467pOcRGR1RfKyIiIiISkuavL+Nfnxbz6DlDSImPdbscR4XlOnRHKjrKw+1TBuD1+7nihdXM\nfmMD89buprbJ63ZpIiIiIiJyENvKG3hmWRH3nD4w4pq5trRrgKkxZgtQBXiBZmvthAOunwncC/gC\nP7OttYsD130f+A7gAZ6x1j4euPwh4BygCdgEXG2treyAx9QuMVEefjl9IIWVDRRXN7Fwwx6eXlbE\nrBFpXDYmw9ElDvLy8pg0aZJjfy+SKWtnKGfnKGtnKGfnKGtnKGfnKOuO0dTi4753NnPN+Ez6p3x9\nYfBIzrm9R+j8wBRr7ZgDm7mAhdbaUdbaMcBVwNMAxpiR7G3mjgdGAecYY3IDt5kPjLDWjgLWA3ce\n+cM4MnExUeSmxjNxQDJ3nz6QP31zOPk7a3jg3S2EwlBUEREREZFI8GJ+KRlJXThraKrbpQSdwxly\n2eohK2tt7X6bicDuwO/DgaXW2gZrrRdYAlwQuM0Ca+2+s5IsBfoeRi2dIjU+lvtm5FJS08S/Pi1x\n7O9G6rcJblDWzlDOzlHWzlDOzlHWzlDOzlHWR6+8rpm5X5Ry3YQ+rS49Fsk5t/ecnn5goTHGC8yx\n1j5z4A7GmFnA/UAmcEbg4nzg18aYnkADcDaw7CD3fw3w/GHW3inioqO4a/pAbn1tHV6fn2+N6k2X\nmIicaigiIiIi4qomr497F23mvGPS6NOji9vlBKX2dioTA8MpZwA3G2NOOXAHa+2r1trhwLnAs4HL\n1gIPsHd45TxgJXvn2H3JGPMzoMla+68jfhQdLDU+lt/PHMrmPfVc+cIqlhV27tQ+rU/iHGXtDOXs\nHGXtDOXsHGXtDOXsHGV9dP78SRHdu8Zw2diMNveL5Jzb1dBZa3cG/rsLmAscbB7dvn3fB2KMMamB\n7b9Ya8dba08FKoB1+/Y1xlwFfAO49FA17P+PlJeX1+nba1Ys5e7TB/KLaTncv3AjT73xUaf9vfz8\nfMcfn7a13Znb+fn5QVVPOG/r9UPb4bat1w9ta1vb+7Yf/s/HLC+s4rZJ2Xz4wQdt7h8J74etOeQ6\ndMaYeCDaWlttjElg79G2e6y18/fbJxcosNb6jTFjgRettbmB69KttaXGmH7A28AJ1toqY8xZwCPA\nqdba3V/7w/vp6HXoDteW8nrumLeRn5w6gDF9klyrQ0REREQkEtQ3e7nihdU8du4QDbUMaG0duph2\n3LY3MNcYs2//f1pr5xtjrgew1s4BLgSuMMY0AzXAxfvd/qXA0bpm4CZrbVXg8ieAOGBB4L4/stbe\ndESPrpMNSOnGjyf35+H3tjLngmEkdmlPbCIiIiIiciT+u2Y3x2Ykqplrh0MeoQsGbh+h2+fBd7fQ\nP6Ub3xrVu0PvNy8vctfNcJqydoZydo6ydoZydo6ydoZydo6yPnyf76zmV4u28Ni5g+nTo2u7bhMJ\nOR/NEToJmJrbk399Wow5Lr3VU6aKiIiIiEj7+f1+VhZV88baMnZUNrK7tok7pg5odzMX6XSE7jDU\nN3v50esb6Bkfyw9O6UdqfKzbJYmIiIiIhKyyumYeXrKVXbXNnD8yjcGp8QxI6Uqclg37mtaO0Cmp\nw9AtNprfzxzKkF7x3DR3LZ8UVh36RiIiIiIi8jWfFlVz86trGZ6ewJwLhnH2sF4MSYtXM3eYlNZh\nionycMW4TO6alsODS7ayeU/9Ud9nW6chlY6lrJ2hnJ2jrJ2hnJ2jrJ2hnJ2jrA9uTWktv1m8hdmT\n+3PFuEyio45uOlMk56yG7giNyEjkW8el86+VxW6XIiIiIiISMsrrmrn/nS3cMrEv4/p2d7uckKc5\ndEehvtnL5f9exR/PH0Z6Ypzb5YiIiIiIBLUWn58fv76BsX2SuGJcptvlhBTNoesE3WKjGdMniRU7\nqt0uRUREREQk6P3702Li46K4fGyG26WEDTV0R2lsn+6s2HF0J0eJ5DG/TlPWzlDOzlHWzlDOzlHW\nzlDOzlHW/2f9rjpeW72bH57Sr8OXAIvknNXQHaWxWUmsLKrBFwJDV0VERERE3FDb5OXBJVu58cQ+\n9ErQVKWOpDl0HeCKF1bxqzMG0j+lm9uliIiIiIgElWavj5+/XUCf7l24ZWLfDj86Fyk0h64Tjeyd\nwKqSWrfLEBEREREJKn6/n8fyComL9nDzyWrmOoMaug5wTO9EvjiKhi6Sx/w6TVk7Qzk7R1k7Qzk7\nR1k7Qzk7J5Kz9vr8PLOsiG0VDfz0tAFHvdZcWyI5ZzV0HWBkRgKrimvcLkNEREREJCg0tvj45YIC\n1u+q494zBtItNtrtksKW5tB1AJ/fz0XP5fP0hcNJjY91uxwREREREVc9tGQrzV4ft08ZQEwnHpmL\nJJpD14miPB5GZSaxrPDoli8QEREREQl128obWFZYxW2T+qmZc4Aaug4yJTeZxRv3HNFtI3nMr9OU\ntTOUs3OUtTOUs3OUtTOUs3MiLWu/388zy3Zw0bHpxMc5N8wy0nLenxq6DnJivx7sqGpkTanOdiki\nIiIikcfv9/P/Pt5BeX0Ls0amuV1OxNAcug40f30Zr3xRyoPfGEz3rjFulyMiIiIi4gi/388fPtzO\nht113HdWLold9Fm4o2kOnQNOH9yTEb0Tue+dLXh9wd8oi4iIiIh0hL8t38mG3XXcP2OQmjmHHTJt\nY8wWoArwAs3W2gkHXD8TuBfwBX5mW2sXB677PvAdwAM8Y619PHB5T+AFoD+wBTDW2oqOeUju8Xg8\n3HRSX25/cyN3zS9gXN8khqcnMLhXfJsTQvPy8pg0aZKDlUYuZe0M5ewcZe0M5ewcZe0M5eycSMh6\n3a5a3t5QxpwLhpPg4Ly5/UVCzq1pzxE6PzDFWjvmwGYuYKG1dpS1dgxwFfA0gDFmJHubueOBUcA5\nxpjcwG3uABZYa4cAiwLbYSE6ysM9p+cwJTeZ7RWNPPb+Nr778hpWH8XC4yIiIiIiwcjn9/PcimK+\nPTqDHppy5Ir2Drls9fCStXb/TiUR2B34fTiw1FrbYK31AkuACwLXnQf8PfD734FZ7a44BCR2ieH0\nwancOimbORcO5+rxWdy9oID/bT/4sgaR+m2CG5S1M5Szc5S1M5Szc5S1M5Szc8I565LqJu6Yt5Hq\nRi9nDEl1tZZwzvlQ2tNG+4GFxhgvMMda+8yBOxhjZgH3A5nAGYGL84FfB4ZXNgBnA8sC1/W21pYE\nfi8Beh/5Qwh+p+Qkk9Qlmgff3cqfLxpOt1h3DkWLiIiIiHSE5durePDdrZw/Mg1zXG+itd6ca9pz\nhG5iYDjlDOBmY8wpB+5grX3VWjscOBd4NnDZWuABYD4wD1jJ3nl4B97Wz96mMayNzkri2MxEXvis\n5GvXRfK6GU5T1s5Qzs5R1s5Qzs5R1s5Qzs4Jx6zfWLubh5ds5efTcrhkdEZQNHPhmHN7HbKhs9bu\nDPx3FzAXONg8un37vg/EGGNSA9t/sdaOt9aeClQA6wO7lhhjMgCMMZlA6aHq2P8fKS8vLyS3rz0+\ni/+u2c3r73zwlevz8/ODoj5ta7ujtvPz84OqnnDe1uuHtsNtW68f2tZ2cG+/8FkJL3xWwrczq6ja\n9Knr9ewTCe+HrWlzHTpjTDwQba2tNsYksPdo2z3W2vn77ZMLFFhr/caYscCL1trcwHXp1tpSY0w/\n4G3gBGttlTHmQaDMWvuAMeYOINla2+qJUUJlHbr2eHbFTrZVNPCz03LcLkVEREREpF38fj9/Wb6T\nj7ZW8tsZufRKiHO7pIjT2jp0MYe4XW9grjFm377/tNbON8ZcD2CtnQNcCFxhjGkGaoCL97v9S4Gj\ndc3ATdbafWcF+S1gjTHXEli24IgfWYi56LjeXPviar4ormFkRqLb5YiIiIiItMkXWDR83a5aHjln\nsM5mGWTaPEIXLMLpCB3A4o17eCm/lCdmDiU6ykNeXuSum+E0Ze0M5ewcZe0M5ewcZe0M5eycUM/a\n7/fz+AeFbKto4Fdn5Lq2ztyhhHrO7dHaEbr2LlsgHWhqbgrdu8bwz5XFbpciIiIiInJQ+47MFZTV\n8+sgbuYinY7QuaSsrpmb567l1knZnNw/2e1yRERERES+5A80c5vK6vnNWWrmgsGRzqGTTpIaH8u9\nZ+by87c24cHDSf17uF2SiIiIiAirS2p5/tNi9tQ38+A3BquZC3IacumiIb3i+fWZuTyweBOrSmrc\nLicitHXKV+k4ytk5ytoZytk5ytoZytk5oZb1W+vKuGdhAROyu/Pw2aHTzIVazh1JDZ3LhqTFc15m\nI79etIXdtU1ulyMiIiIiEWpndSPPLNvBI+cM5txj0ugWGxrNXKTTHLog8e/PivlgSyWPnD2YuBj1\n2SIiIiLirN+9t42U+BiuHp/ldilyEDrLZZD71nG9yUiK4753tlDT2OJ2OSIiIiISQfK2VPC/HVVc\nODLd7VLkMKmhCwJ5eXl4PB5+PLk/PeNj+fbzq/jTsh2EwtHTUBPJ46udpJydo6ydoZydo6ydoZyd\nEwpZb6to4PG8Qu6ankP3EF00PBRy7ixq6IJIl5gobp2YzXMXj+CDLZUs317tdkkiIiIiEsZqm7zc\nu3Az14zPZGhagtvlyBHQHLogtaSgnJfyS/n9eUPweL42VFZERERE5KjUNnn52VubGNwrnptP7ut2\nOXIImkMXYk7JSaaxxccn26vcLkVEREREwozP7+f+d7bQP6UrN57Ux+1y5CiooQsCBxvzG+XxcNmY\nDJ5bUay5dB0oksdXO0k5O0dZO0M5O0dZO0M5OydYs/7rJ0XUNXm5ZWI2UWEwGixYc3aCGrogNnFA\nMjVNXj7bqUXHRURERKRjLNhQxgdbK7n79IHERIV+MxfpNIcuyC3auIcXPy/liZlDiI1W/y0iIiIi\nR251SS13LyjggRmDGJjaze1y5DBoDl2IOi03hfTEWJ5bUex2KSIiIiISwhZu2MPdCwqYfWo/NXNh\nRA1dEGhrzK/H4+EHk/rx1voy1u2qdbCq8BTJ46udpJydo6ydoZydo6ydoZydEyxZf7i1gr8uL+KB\nGYOYkN3D7XI6XLDk7AY1dCEgJT6Wa4/P4qmPtNi4iIiIiBwev9/P35fv5LZJOjIXjjSHLkT4/H6+\n9+o6Ljounam5Pd0uR0RERERCxOc7q3k8r5A/fXO41jcOYZpDF+KiPB5uOqkvf1pWRLPX53Y5IiIi\nIhIi5n6xi5kj0tTMhamYQ+1gjNkCVAFeoNlaO+GA62cC9wK+wM9sa+3iwHV3ApcFLs8HrrbWNhpj\nJgB/AGKBFuAma+0nHfWgQk1eXh6TJk065H4jMxLpn9KVhRv2MGNYLwcqCz/tzVqOjnJ2jrJ2hnJ2\njrJ2hnJ2jttZb9xdx5rSWm6f0t+1Gpzgds5uas8ROj8wxVo75sBmLmChtXaUtXYMcBXwNIAxZgBw\nHTDWWnssEA1cHLjNg8AvAre5K7At7XDpmAyeXVFMZUOL26WIiIiISJD7+/928q1RvekWG+12KdJJ\n2jvkstXjs9ba/U+9mAjsDvxeBTQD8caYGCAe2BG4biew7/Q6yftdHpEO59uEEb0TmZKbwiPvbdUJ\nUo5ApH5z4zTl7Bxl7Qzl7Bxl7Qzl7Bw3s15dUkvBnnrOHh7+I7si+Tnd3iN0C40xy40x1x1sB2PM\nLGPMGmAecCuAtXYP8AiwDSgCKqy1CwM3uQN4xBizDXgIuPPoHkZkuXp8JnvqWnht9e5D7ywiIiIi\nEaepxcfvPyjkynGZxEXrtBnhrD3/uhMDQyNnADcbY045cAdr7avW2uHAucCzAMaYXOA2YACQBSQa\nYy4N3OT9VNZ2AAAgAElEQVTPwK3W2n7AD4C/HO0DCWWHu25GbHQUd04dwD9XFrNhd13nFBWmInmN\nEicpZ+coa2coZ+coa2coZ+e4lfU/Py0mMymO0wdHxtnRI/k5fciGzlq7M/DfXcBc4GDz6Pbt+z4Q\nY4zpBYwHPrTWlllrW4BXgJMDu06w1s4N/P5SW/e5z/7/SHl5eWG1nZ+ff9i335z/CbdOzOYX8zfx\nyqIPgurxaFvb+fn5QVVPOG8fyeuHtrUdzNt6/dC2to9+u6Csntfyi5kQu/PLM1sGU32dsR0J74et\naXMdOmNMPBBtra02xiQA84F7rLXz99snFyiw1vqNMWOBF621ucaY0cBzwPFAA/A3YJm19kljzArg\nB9baJcaYacBvrbXHt1aH1qFr3TubyvnjR9u594yBDE9PcLscEREREXGR1+fntv+u56yhqZyts6KH\nldbWoYs5xO16A3ONMfv2/ae1dr4x5noAa+0c4ELgCmNMM1BD4EyW1tpPjTH/AJazd9mCFQTOgAl8\nF3jSGNMFqA9syxGYmptClxgPv1m8mSdnDaNH10P9k4qIiIhIuPrP6l3ERUcxY2iq26WIQ9o8Qhcs\nwv0IXV7e0a+b8fTSHWwtb+BXZw4kSotGtqojspZDU87OUdbOUM7OUdbOUM7OcTLrkuomvvfaOn53\nzmCyk7s68jeDRSQ8p1s7QqdT3oSJa47Por7Zy78/LXG7FBERERFxmNfn58ElW7no2PSIa+YinY7Q\nhZHdtU1879V13DF1AKOzktwuR0REREQc8sJnJXxSWMUD3xhEdJRGa4UjHaGLAL0S4ph9an8eeHcr\ndU1et8sREREREQfkF9fwUn4ps0/tr2YuAqmhCwJtnYb0cI3r250xWYk8/5mGXh5MR2YtrVPOzlHW\nzlDOzlHWzlDOzunsrAsrGvjNos38ZEp/eifFderfCmaR/JxWQxeGrj2+D/PW7mZ7ZYPbpYiIiIhI\nJymtaeKnb23iqvFZjO/b3e1yxCWaQxemXsov5ZPCKn47I/fLBSVFREREJDzsqWvmR69v4NxjenHB\nyHS3yxEHaA5dhDl/RBqVDS0s2ljudikiIiIi0oFqm7zcOW8j0wb3VDMnauiCQWeM+Y2O8vDDyf2Y\ns3QH63fXdfj9h6pIHl/tJOXsHGXtDOXsHGXtDOXsnM7I+m/LdzK4VzyXju7d4fcdqiL5Oa2GLowN\n6RXP9Sf04YkPCgmFobUiIiIi0rYPtlTw4dYKrjuhj6bVCKA5dGHP5/dz09x1XDEug5P7J7tdjoiI\niIgcoZ1Vjdz6n/X86oyBDEtPcLsccZjm0EWoKI+HK8dl8vflO/GFQPMuIiIiIl9XVtfMnW9t5Mpx\nmWrm5CvU0AWBzh7ze2K/7sTFRLGkoKJT/04oiOTx1U5Szs5R1s5Qzs5R1s5Qzs7piKybWnz8ckEB\n0wencs7wXh1QVfiJ5Oe0GroI4PF4uHxsBvbzEh2lExEREQkxT360nfTEOJ0ERQ5Kc+gihM/v5855\nm2j2+rhreg7J3WLdLklEREREDuHNtbt55Ytd/P68IcTHRbtdjrhIc+giXJTHw31n5TIsPYFfLthM\nU4vP7ZJEREREpA1rS2v56/Kd3D09R82ctEoNXRBwasxvdJSH70zIomd8LI/mbYvIpQwieXy1k5Sz\nc5S1M5Szc5S1M5Szc4406/L6Zn61aDO3TcomO7lrB1cVfiL5Oa2GLsJEeTzcPqU/hRWNPP9pidvl\niIiIiMgBvD4/9y3ewvRBPZk4QMtOSds0hy5CldU1c8ur67hjan+Oy0xyuxwRERERCXg5v5RlhZXc\nd9YgoqO0eLjspTl08hWp8bHcMjGb3767lfK6ZrfLERERERGgscXHi5+X8N0T+qiZk3aJOdQOxpgt\nQBXgBZqttRMOuH4mcC/gC/zMttYuDlx3J3BZ4PJ84GprbWPguluAmwL3+4a19icd9JhCTl5eHpMm\nTXL8757UvwcrdlTxwucl3HBiX8f/vhvcyjrSKGfnKGtnKGfnKGtnKGfnHG7Wr63exbD0BHJT4zux\nqvATyc/p9hyh8wNTrLVjDmzmAhZaa0dZa8cAVwFPAxhjBgDXAWOttccC0cDFgeumAucBx1lrRwIP\nH+0DkSPzrVG9ebegnGWFlW6XIiIiIhLRlhVW8tLnpVw3IcvtUiSEtHfIZavHe621tfttJgK7A79X\nAc1AvDEmBogHdgSuuxG431rbHLiPXYdTdLhx89uEXglx/GJaDg8t2ca2igbX6nBKpH5z4zTl7Bxl\n7Qzl7Bxl7Qzl7Jz2Zv32+jIeeW8bd0/PoU8PndXycEXyc7q9R+gWGmOWG2OuO9gOxphZxpg1wDzg\nVgBr7R7gEWAbUARUWmsXBm4yGJhsjPnYGPOuMWb80T4QOXIjeidy7fFZ3D2/gJrGFrfLEREREYko\n5fXNPL10Bw+dPZgRGYlulyMhpj0N3cTAcMoZwM3GmFMO3MFa+6q1djhwLvAsgDEmF7gNGABkAQnG\nmEsDN4kBUqy1JwKzAXu0DySUBcO6GWcNTeX47O7c/87WsF6fLhiyjgTK2TnK2hnK2TnK2hnK2Tnt\nyfr5T0s4Lbcn/bTe3BGL5Of0IRs6a+3OwH93AXOBg82j27fv+0CMMaYXMB740FpbZq1tAV4BTg7s\nuj2wjbX2E8BnjEltq479/5Hy8vLCajs/Pz8o6rn+hD57vyGa93FQ1KPt0N3Oz88PqnrCeTtYXj+0\nre2O2tbrh7YjbXtndSOLNu5hUNOWoKgnVLcj4f2wNW2uQ2eMiQeirbXVxpgEYD5wj7V2/n775AIF\n1lq/MWYs8KK1NtcYMxp4DjgeaAD+Biyz1j5pjLkeyLLW3m2MGcLeE6v0a60OrUPnnM+Kqnn4vW38\n+ZvDiYvRqhYiIiIinemBd7eQmdSFK8Zlul2KBLkjXYeuN/C+MeZTYCnwurV2vjHm+kBTBnAhkG+M\nWQk8TuBMltbaT4F/AMuBzwP7Ph3471+AgcaYfOB54Iojf2jSkUZlJZGb2o1XVpW6XYqIiIhIWCso\nq+d/26u58Nh0t0uRENbmEbpgEe5H6PLygmvdjB2VjXz/P+t45pvDSekW63Y5HSrYsg5Xytk5ytoZ\nytk5ytoZytk5rWXt8/v5yZsbObl/D84fqYbuaEXCc/pIj9BJBOrTowvTBvXkb8t3ul2KiIiISFh6\n5YtdeH1+zjsmze1SJMTpCJ0cVE1jCzfOXcfNJ/flxH493C5HREREJGxsq2jgh/9dzxMzh5LZvYvb\n5UiI0BE6OSyJXWK4fUp/Hnt/G+X1zW6XIyIiIhIWvD4/Dy/ZyhXjMtXMSYdQQxcE2joNqZuOzUjk\n1NyUsBp6GaxZhxvl7Bxl7Qzl7Bxl7Qzl7JwDs/77/3YSHxfNOcN7uVRReIrk57QaOmnT5WMy+Ghr\nJVvK690uRURERCSkLSusZOHGPfxkSn+iPF8bOSdyRDSHTg7p358Vs660jrum5+DRi4+IiIjIYSuv\na+bGuWv56Wk5HJeZ6HY5EoI0h06O2Pkj0tle2ciijeVulyIiIiISkp76eDunD+6pZk46nBq6IBDs\nY367xERxx9T+zFm6g6KqRrfLOSrBnnW4UM7OUdbOUM7OUdbOUM7OycvLY1VxDV+U1HLp2Ey3ywlb\nkfycVkMn7ZKbGs/lYzO4Z0EB9c1et8sRERERCQl+Pzz18Q6uPT6LrjH66C0dT3PopN38fj8PvbeN\nFq+PO6cO0Hw6ERERkUN4Y+1uFqzfw6PnDtZnJzkqmkMnR83j8fD9idnsqGrkpfxSt8sRERERCWoV\n9c38bflObpnYV82cdBo1dEEglMb8domJ4u7pA3k5v5Tl26vcLuewhVLWoUw5O0dZO0M5O0dZO0M5\nO+PPnxQxrFs9uanxbpcS9iL5Oa2GTg5bemIcP5uWw4PvbqWkusntckRERESCzvLtVazYUc2pvfRZ\nSTqX5tDJEXvx8xIWbyrnvrNySekW63Y5IiIiIkGhprGF776ylh+d0o9xfbu7XY6Eidbm0MW4UYyE\nh28em059s48r/r2KvsldGZoWz9C0BE7LTaGLzuIkIiIiEaixxccTH27nxOweaubEEfrUHQRCdcyv\nx+PhinGZvHz5cdw6MZuclG4s3riH372/ze3SWhWqWYca5ewcZe0M5ewcZe0M5dyxCisaeHXVLu5b\nvJnL/r2KhhYf152QBShrp0RyzjpCJ0ctLiaK4ekJDE9PYMbQVL77ylqWFVYyIbuH26WJiIiIdKqS\n6iZ+8N/1TMpJZnzf7lx9fBaZSV3cLksiiObQSYdbVljJUx/tYM6Fw4iL1kFgERERCU9en5/b39zI\n8dlJXDwqw+1yJMxpHTpxzITsHmQnd+GVL7RWXShpaPGxu7YJXyd8yVNa04T9vIRfL9rMprK6Dr9/\nERERN/xteRFx0R7Mcb3dLkUi2CGHXBpjtgBVgBdottZOOOD6mcC9gC/wM9tauzhw3Z3AZYHL84Gr\nrbWN+932R8BDQC9r7Z6OeEChKC8vj0mTJrldRoe64cS+3PraOqYN6klaQpzb5XwpHLM+WjWNLXyy\nvZpnlu3A6/NT2+Rlam4K1xyfdcRnL83Ly2P4mBN4Mb+EtaV1FFY2MGlAMsPSE7hj3iYuHZPBzGN6\naZHVDqDn9JHx+vx8vrOGD7dWkJHUhVMHJtOrjdcq5eycUMva6/Ozo7KR9bvraPT6GNcniYwQGG4X\najkHo7wtFSzaVM4fZw0lqo33M2XtjEjOuT1z6PzAlDYaroXW2tcAjDHHAnOBQcaYAcB1wHBrbaMx\n5gXgYuDvgX2zgdOBrUf3ECQYZXXvwrnHpPGnZUXcOXWA2+XIARpbfMxdVcoHWyrZVtHAsLQEZk/u\nz5g+SVQ3tvDPlcVc++Iahqcn8K1R6RyXmdTu+27y+sgri+WxV9ZwxpBULh+bwbGZiV8Ovz0huzv3\nv7OFHZUN3HhS3zbfBCWyVTW08OyKYoqqGumVEMu0QSmH9Vw8kN/vZ+2uOuatLePDrRX0Topj0oBk\ntlU0cP0ra7l8bCazRqR14COQUNDk9R3W9ACvz8/8DXt4e10Ztc1eSmuaSO4aw+Be8XSJieIvnxRx\n9rBeXD0+U19ahbFtFQ08nlfIb87MJVlLN4nL2ntSlFZfkay1tfttJgK7A79XAc1AvDHGC8QDO/bb\n93fA7cBr7a42TIXrtwnmuHSueXENa0trGZae4HY5QPhm3V4+v5/8nTX84aPtZPfoyjXHZzGid8JX\nPswkdYnhhhP7cvGo3iwrrOI3i7fwkyn9Gdun7VMvF1c38saa3SzcWM6QXmn8fmofsrp//Vvq7OSu\nPHT2YG5/cwOvrtrFBSPTO/xxRpJwe043tfh4t6CcdwvKWVVSy+ScZM4Z3ouiqkZ+9/42+nTvyqDU\nbtQ1+0juFsM3hqaSEn/wD1Nen5/Ne+pZU1rLml11rC6pAWDG0F48OWsYvZP+74jcJaN7c+e8TSTG\nRTN9cM+v3Ve45RzMOjtrv9/PxrJ6Pt5WyeqSWlYWVZOd3JWbT+rL6KzWvzDw+f18vK2Svy7fSY8u\nMVw6JoPU+FjSEmNJ6vJ/H6cq6pv56Vub6JUQy3nHBO8XBHpOHzm/38/v8wq5dEwGQ9LiD7m/snZG\nJOfc3iN0CwNN2Rxr7TMH7mCMmQXcD2QCZwBYa/cYYx4BtgH1wNvW2oWB/WcC2621nxtjOuaRSNDp\nFhvNleMy+eNH23n03CFER+mbSjeV1zVz14ICGlp8mOPSmT6oZ5vfHid3i+WMIamkJcbxwDtbeGLW\nUNIS4mjx+SmsaCC5WwwJsdFsKKtj8cZylhSUc/rgnvx2Ri79U7q1WUtCXDR3Th3A7W9sJKVbDFNz\nv/4BWsJTi8/PgvVllNQ00eT1kxgXzaisRIalJfDJ9iqeWbqD9MQ4ZgxNZfbk/l9p1s47phdvr99D\nZUMLyd1i2FbRwLUvrWFcnyTG9EliZEYiRVWNvLupnMLKBnZUNpIaH8sxvRMY2TuBb45MZ0DPrgc9\nKpyR1IU7TxvAL97exCk5yVpLMwxtq2hgwfoy3i2oIDoKTurXgzOGpHL36QNZuaOa3yzewiNnD6Zf\nStev3baxxcdvFm9mV20zV4/P5KR+PVp9/UzuFsuPJ/fnjnkbOWNIKl31XAo7Czbsob7Fy7nDe7ld\nigjQvoZuorV2pzEmDVhgjFlrrX1//x2sta8CrxpjTgGeBYYaY3KB24ABQCXwojHmUvYOyfwpe4db\n7hPRn/TDeczvGUN68s6mcp7/rITLxrh/9qdwzrot2ysbuGfBZk7JSebysRmHNQxoTFYS549M5/Y3\nNjIkLZ7l26vo0TWGqoYWapu8DOjZjROyu/PMhcO//PDdnpz79ujKr84cyB3zNnFcRhKpCRqyciRC\n6Tnd2OLjvsVbqGnyMjorkeS4aCrrW3js/UJ2VjfSP6UrV47PZHJOykFvHxsdxTkHfIC6enwWH2yt\n5LOiap7/tITeiXFMHpjMrBFpZHXvQveu7V+dZ0iveIb0iuf1Nbu58NivHjkOpZxDXUdm7ff7Wbyp\nPDBfspKzhvTkl6fnMLBnt6+8Dp7UvwfXNmTxi/mbuGR0BlWNLcRGeegWG82OqkaWbqtkYM9uPDFz\nIDHt+HJyYGo3hqbFs3jjHr4xLDg/9Os5fWSqGlr48ydF/OrM3HZ/Ua2snRHJOR/yayNr7c7Af3ex\ntxmb0Ma+7wMxxphewHjgQ2ttmbW2BXgFOBkYyN4m7zNjzGagL/A/Y0yb4672XywwLy8vrLbz8/OD\nqp6O3I7yeDi1Wwkvf1rE+l11rtcTadten58HXlvK915ZzTnDe3HFuEw++OCDw76/rKoN3DJx73Ck\na/pWc03mHl66/Dhev3o0l6btZlBDwVeaufz8/Hbdf25qPCMT6rjvjU+DIq9Q3A6V148dlY3c9t/1\nVFeUcV6PEi4fm4k5rjfDmzdzZUYZz108gidnDSNqx6rDuv/Pl39M0q413DF1AM9ePIJZySX03LOO\nYekJdO8ac9j1josp5h/Lt7Ortimo8ouk7fa+fhxqu6S6iRuf/x//+KiAPj268NT5QxnatJmda1Z8\n2cztv/9ZQ1M5OamKBZ8VsKeumaKqJhZ+tomSHYV8Z0IWP5nSn48/bP/r5wUj0/nnsq28/35w5avt\no9t++M0VnNy/B0N6xQdFPdoOvffDo9luTZvr0Blj4oFoa221MSYBmA/cY62dv98+uUCBtdZvjBkL\nvGitzTXGjAaeA44HGoC/AcustU8e8Dc2A+PaOsul1qELfe9s2sO/Vpbw5KyhxGn4iSPqm7384u0C\nAH58ar+gPetafbOX77y09wP5sRmJbpcjnWBZYSUPLdnG5WMzOHd48J/d9B//28nmPfXcffpAt0uR\nI/TOpj388aMdXDAyDXNcb1eG/Pv9fq5/ZS03nNjnkHOQJTSU1Tbz3VfW8PQFwzWqRFxxpOvQ9Qbe\nN8Z8CiwFXrfWzjfGXG+MuT6wz4VAvjFmJfA4e89kibX2U+AfwHLg88C+Tx/kbwT/yuZy1KYMTKFP\njy7Yz0vcLiUitPj83P/OFjKS4njw7EFB28zB3rmW103ow+8/KKS+2et2OdKBfH4/f//fTh59v5Bf\nTs/hvGPSgr6ZA7h4VG+2VjQwb10ZbX3pKcFp8556/vjRDh6YMYhLRme4Nn/b4/Fw/og05n6xy5W/\nLx3L5/fz+w8LmTE0Vc2cBJ02j9AFi3A/QpeXFxljfktrmrhp7lqemDmUzIOc/dAJkZC11+fnvne2\n0NTi467pOcQexum4O8rh5uz3+/nd+9uobfLyi2k5IfGhP1gE63N63a5afvfeNuLjorlres4Rr2no\nlk1ldTzw7t5VdW46qS81BZ8FZc7h6Gie0y0+P7e8to6Zx6Rx1tDUDq7s8DW2+Ljs36t49NzB9O3x\n9ZOtuClYXzuC1Z8/KWJVSQ0PzBh02O+rytoZkZDzkR6hE+kw6YlxfPO4dP740XZ9691JvD4/Dy7Z\nune4pUvN3JHweDzcOjGbndVNzFtX5nY5cpS2ltdz1/wCLh6dwcNnDw65Zg72zu+cc8Ewrh6fxf3v\nbOH93bHUNekIcrBbsGEPSV2iOXNIcJw5t0tMFDNHpPH3/+10uxQ5Ch9urWBJQTl3Tx8YMu+rEll0\nhE4c1ez1ccMra7l2QhYn9092u5yw4vX5eWjJVsrrm7n3jNyQPO36tvIGfvTGBn47I5fc1EOv7SPB\np7SmiR/8dz1Xj8866Hpuoai4upGnlxaxprSWS8dk8I1hqQdd+kDc5fX5ufalNfzwlOyjWoC+o9U3\ne7n2xTX8fFoOx/QOjjVZpf0aWnxc99IafjS5X5vrFIo4QUfoJCjERkfxvZOzeeqjHZov1cFeX7Ob\n4uqmkG3mAPqldOWGE/vwm8VbqGpocbscOUxNLT5+uaCAmcekhU0zB3vXqLtreg6/mJbD/PVl/Pad\nLXh9wf9laKT5aGslyV1jgu7kSt1io7lqfCZzlmp0Sij696fFDEuPVzMnQS00P/WFmbZOQxqOxvRJ\nYnRWIr97b5vjb27hmrXP7+eFz0u4ZWLfoGjmjibnaYN6MmlAMle/uJo/fFjInrrmDqws/ATTc/rJ\nj7bTp3sXLjquzVVoQlJeXh7H9E7g4bMHU17fwvOfFrtdUtg60uf0koJyzhjSMyjn4E4f3JNmr59X\nV+0Kmi8Dgum1I1h9vrOGeevKuP6EPkd1P8raGZGcs/uf/CQi3XJyNqW1Tfx1ueYVdIS5X+wiM6lL\n2AxTvOb4LJ6cNZRoj4cfvr5BTV0ImL++jPziGn5wSr+g/EDdUeJiovjx5P7MXbXry7XqxH31zV6W\n76jmpP493C7loKI8Hmaf2p/Fm8q5yq7m358Va5RKkCurbeb+d7Yw+9T+9EqIc7sckTZpDp24pqK+\nmVteW8/3Tu7LCf2C8004FOybd/b4eUPIcunsoZ3pz8t2sH53PXdPzyE+LtrtcuQgCsrq+cm8jTx0\n9iAGpHRzuxxH/HV5ESXVTdwxdYDbpQh7v1B4f3MFvzoz1+1SDmn9rjpe/qKUVSU13DV9IEN6hccX\nceHE7/dz51ubGNE7gcvHZrpdjsiXNIdOgk5yt1h+NLkfj+UVar7UEWr2+nhgyRauHJcZls0cwBXj\nMklPjOWHr6+nrFZH6oKN3+/n9x8Ucs3xWRHTzMHetepW7Khm8556t0uJeBX1zTy7opjzR6a5XUq7\nDEmL586pA7hibCYPL9lKS5AMwZT/s3hTORX1LXx7dIbbpYi0ixq6IBDJY35HZyUxeWAyj+UVOjKf\nLtyyfmZZEb0S4jh7mPvrLe2vI3OOjY7ih6f049SBKXzvtXVq6g7g9nN63a46KhpaOCOMToJyMAfm\n3C02mguPTddcuk5wOM/pZq+PexdtZmpuCmP7dO/Eqjre6YN70ishlv+sdmfhcbdfO4JVdWMLzyzd\nwfcnZXfYovTK2hmRnLMaOnHdteOzKKpq4K31e9wuJaS8V1DOx9sq+fHk8J6zBHvXqbtkdAZTc1P4\n50p9gA4mH2+r5OT+PTrsg08oOXd4L1YW1bCtosHtUiLWcyuKSQicRTLUeDwevntCH57/tIRyzRMO\nGn/+pIiJA5IZnq4lJiR0qKELAuG+qv2hxMVEcefUAfzlkyK2lnfu8KVwyXpbRQNPfLidn0/LIalL\njNvlfE1n5XzxqN68t7mcnVWNnXL/ocjN53SLz8/b6/dwepgfnYOD5xwfF835I9J0lK6Dtfc5vXF3\nHW+uK+O2Sf1Cdl3AASndOHNIT/7f0h2O/+1weT/sSKuKa1i6rYprjs/q0PtV1s6I5JzV0ElQ6J/S\njSvGZvDo+4X4QuBEPW7y+vw8+O5WrhyXGXGT6bt3jeG8Y9J4LG8bRWrqXPfWujL6JXclp2fkzJ07\n0MwRaSzfXs32Sh2lc1Jji4+7FhRw68RsUhNi3S7nqFw2NpO1pbUsK6x0u5SI1uLz8/gHhVx/Qh8S\ndAIuCTFq6IJAJI/53d/Zw3sR5dm7QHZnCYes31i7my4xUUE3b25/nZnzt0b1ZkTvRG59bR3rdtV2\n2t8JFW49pxtbfPxrZTFXh+BQtyPRWs4JcdHMPKYXz39a4nBF4etQz+mS6iZ+9PoGxvVJ4pScZIeq\n6jxdY6L4/qRsfv9BIXVNzi1lEA7vhx3p5fxSeiXEcurAjn9OKWtnRHLOaugkaER5PNw2qR/Priim\ntEbrOx1MUVUjz64o5taJfcN+3lxrusREccW4TH44uR+/XLBZzxWX/Gf1LoamxTNM80yYNSKN5dur\nWFOqLxg6m9/v595FBUwc0IMfntLP7XI6zNg+3RmTlcTTy5wfeimweU899vMSbjk5O2LfWyW0aR06\nCTrPrdjJul113HvGQL2w7sfn9zP7jY2c1L8H3zw23e1ygsJL+aXMX1/Go+cO0RAZB9U2ebnKrubh\nswfRP4KWKmjLe5vL+fvyncy5cDgxEXiCGKfkF9fw6Pvb+NM3h4fsvLnW1DZ5uXHuWq4al8lpg8J/\nXmqwqGxo4eZX13LN+CzlLkFP69BJyPjWqN4U1zTx3uYKt0sJKm+uLaPZ6+P8EaGx1pITLhyZxsje\nifxm8Wa8WsvJMS/nl3J8dnc1c/s5ZUAy6YlxnTpkXGDuF6XMGpEWds0c7B2+e8/pA/njR9vZVauR\nB07w+/08+v42JuekqJmTkKaGLghE8pjfg4mNjuIHk/rx1MfbqW7s2AXHQzXroqpG/v6/nfzglH4h\ncXp4p3L2eDzcfHJfYqOi+OlbG6mMwAXqnX5Ol9c389rqXVwxNrIW3D1UzvtOQf+vlcUd/roVaVrL\nemdVI5/trAnrs6rm9OzGucek8fCSrdQ3d+58ulB9P+xIb6/fQ3F1Y6cve6GsnRHJOauhk6B0TO8E\nThmQzDNLi9wuxXVFVY3c/uYGrhqfGdFnE2xNdJSHu6bnMLhXPDfNXcvnO2vcLimszfl4B6cP7klG\nUhlPptYAACAASURBVBe3Swk6OT27MSU3hbvnF+gISyd4Kb+UGUNT6RYb3sOrvz26N2kJcfz4jQ2U\naX26TlNU1cifPyniJ1MGEBetj8MS2jSHToJWXZOX615ew+xT+zM6K8ntclyxr5m7eFQG5wzv5XY5\nQW9ZYSUPLdnG/WflMijClnRwwgdbKvjzJ0X88fxhdI3RB6CD8fn9/GtlMa+t3s11E7I4Y0jwno02\nlJTWNHHj3LX86ZvDSekW2ssUtIff7+dfn5bw1roynpg5hOQIeMxO8vr8/Oj1DUwemMwFIzUnXUKH\n5tBJyImPi+bWidk8+v42R0/lHCxKa5r4yZsb1cwdhgnZPbjppL7c984Wmlp8bpcTVpq8Pp5euoNb\nTs5WM9eGKI+Hy8Zm8tsZufxzZTHvbip3u6SQV9/s5TeLN3PByPSIaOZg7xDeS8dkcGK/Hjy3UgvX\nd7R/f1ZClxgPszQnXcJETHt2MsZsAaoAL9BsrZ1wwPUzgXsBX+BntrV2ceC6O4HLApfnA1dbaxuN\nMQ8B5wBNwKbA5RG5qmZeXl5Er27flhP69eDDrZU89fF2fjS5/1HfX6hkXVHfzB3zNjLzmF4h2cy5\nmfPU3BTeKyjH5pdy2Zjwn+flVNavrtpF/5SujOkTmUfLDzfn3NR47pg6gHsWFHB8dnedhfUwHJj1\nHz7cTt8eXfn26N4uVuWOy/5/e/cdX1V9/3H8dZMQCCvsAGFvZCkiKA4QsdUqLuqn+rNDraNqa1Hr\nXtXaukqrVrSltXVV64cqKE5EVARkKSPKXiEJZBBGBmTf3x/3RK8pgZvk3nPX5/l48OCee8+5+ead\nb07u95zvGN2Vq/67nvOP6UzPdi2C+t7R8vcw2DYWlPLm1wXMuHCwa5PrxGvWbovnnAO9zOoFJqrq\ncXUbc475qjpKVY8DLgdmAohIH+BqYLSqjgASgUucY+YBw1R1FLAJuLPR34WJab84MZ2M3FIWxcms\nlxVVNdz1/lZO69uOH46Mvw8wwfCLE3sw56t8dheVh7soMWH/oUp0TR7XjEsPd1GiytAurTihZ1te\nsTssjbZzfxnLs4q4/qT4XHsztUUSF4/ownMrbDx5MByqrObRTzK5YXwPOrdKDndxjAmahvSbqfdM\nqqr+q6m2BmrnbS4CKoGWIpIEtARynGM+VNXaPlHLgB4NKEtMiderCYFKaZbI7RN789TiLPY2cYB4\nNGQ9KyOfzq2T+dnxoZ11K5TCnXNam2RkVBpPLNpJNIwTbgo3sn51TR4T+7enR2pw7xBEk8bmfMWY\n7nywqZCcA2VBLlHs8s/636tyuWh457i+w3nBsM5sLTxERm5wJ3wK93k6HJ5fuZtBnVoyoV97V79u\nPGYdDvGcc0Pu0M0XkZUicvXhdhCRC0RkPfAecCOAqu4FpgM7gV3AflWdf5jDrwTebWjhTfwY2qUV\n3x/ckWeXZoe7KCFVUV3Dm18X8PMTusfl1ehgmjq8CwfKqli0Iy57cgfN17klLNiyj8uOjf3uq6HQ\noWUzLh6ZxkybsbfBMvcd4sucYs4/Jr7HOSUnJXDFmG7MXJZDTYxfoAqlLXsO8vHWfVx3UtzePzAx\nLNAG3clOd8qzgRtE5NS6O6jqHFUdCkwBXgIQkf7ANKAP0B1oLSKX+R8nIncDFar6SqO/iygXz+tm\nNMSPj+vKpoKDfJ7Z+A/okZ714h376dOhBb2CPFbCbZGQc2KCh2tP7MHfl+fE9AQpocw6a38ZD360\nndsn9qZ9y/iYjKI+Tcn5wuGdydx/iJXZRUEsUeyqzfrlVblMHdGZlnF8d67WxP7tqfF6+XRb8IYe\nRMJ52i1er5e/Lcvhp8d3I7VFQNNHBFU8ZR1O8ZxzQA06Vd3t/F8AzAYON46udt/PgCQR6QSMAZao\naqGqVgFvAONr9xWRy4EfAJcd7r38+f+QFi1aFFPbGRkZEVWeSN1unpTAbyb05rEFW3j348VhL08o\ntueu38MA9kRMeRq7nZGRERHlOa57G1K9B5n+9oqIKE8otkN1/iirquG+eds4JbWUsh1rI+b7jcbt\n5Z8v4Zpx6fx1aQ6ffhb+8kT6dkZGBtv3HmLNrhK6HNgS9vJEwnaCx8M1Y9N5dtE2Pl4Y/vJE2/aC\nrfvYf6iKtns2RER5bDs02/Hwebo+R12HTkRaAomqWiwirfBNZvKAqs7z26c/sE1VvSIyGpilqv1F\n5FjgZeAEoAx4HliuqjNE5Cx83TEnqOoejsDWoTP+Xl6Vy5pdxTxy9gASE2KnW+L2vYe48/0tvHzJ\ncJJi6PsKt7ziCn755kamnzOQXu2j+86nm2Yuy6HwYCV3nt4n3EWJCV6vl7ve38rxPdrywxG27tWR\nVNd4ufntTUwe0IEpcd7dsq4H52+nT/sW/DSKx1i7LXPfIX7zzhYeObs//Tva+qQmujVlHbo04DMR\nWY1v8pK3VXWeiFwrItc6+0wFMkRkFfAkzkyWqroaeBFYCdRe4p3p/P8XfBOofCgiq0TkmUZ+bybO\nXDrKN/Pjq6tja+a4OV8XcO7QztaYC7K0Nsn8ZHRX/vTZTqprbPxJINbnl7Jgy16ut7EmQePxeLj+\npB78Z3UuhU2c3CnWzfm6gGYJCZwThUu2hNp1J6Xz1roCsm2SnYBUVNfw6CeZXD6mmzXmTEw76h26\nSBDrd+gWLYrfdTMaq7C0khvmbOCuSX0Z2a11wMdFatZFZVVcrut47odDY2KsUqTlXOP1cus7Wzi5\nTyoXDY+tuyPBzrqyuoYb5mzk/47tysT+7s4EF8mClfNzK3aRW1zO3ZP6BqFUsWdjQSm3vb2RZy4a\nRnpq83AXJyL9NyOfFVlFPHJ2/yZNnhVp5+lQeObzbApKKrhvct+wTjQWD1lHgnjIuSl36IyJOB1b\nNePm03rx6Cc7KCqrCndxmuzfq3M5pU+7mGjMRaIEj4ebT+3JK6ty2WVr0x3R61/lk9Y6mQn92oW7\nKDHpMmdyp+VZNvtqXevzS7nng22c17XcGnNHcOGwzhwoqwzqBCmx6MucIj7PPMDNp/WyWaNNzLM7\ndCaqzVyWQ35JBfecEb1Xu7/KLeGhBduZedFQ2oZh9q14MmttHsuzinj0BwNIsD/w/6O4vIorZ63n\niSkDSY/jNedCbXnWAf66NIe/Tx0aU+OAm6K8qoar/rue605KZ3xvu5hwNF/nlfDQRzv4xw+HxvUa\nffXxer1Mm7uJC4d1sZ4GJqbYHToTk352fDc27znIiqzonA68xuvliUVZ/HJ8T2vMueCi4V0oq6rh\n3Q2F4S5KRHpz3R7G9WxrjbkQO6FHW1olJ7KkCUuwxJpZa/MY1LmlNeYCNCytNSf0aMsLX+wOd1Ei\n0hc5xZRW1HBqX6tPJj5Ygy4CHGkaUnNkzZMS+OX4njy9JIvyANYai7SsV2YXkZzo4eTeqeEuSlBF\nWs61EhM83HJaL174YjcFpRXhLk5QBCvrqhov767fw1SbgfGwglmnPR4Plx6bxqurc4mGXjKhtruo\nnDlfF3DN2HQgcs8fkeaqsd35ZOs+Nu852KjjYzXnGq+XF7/YzWXHpUXMHfBYzTrSxHPO1qAzUe+E\nnm0Z0Kkl/1mTF+6iNNgbXxVwwbDO1r/fRX3ap3D24I689EVszZLaVJ9u20fXtsn07ZAS7qLEhRN7\npVJV42VldnG4ixJWXq+Xp5dkc/HINNLaJIe7OFGlbYskrjyhO08tzqLGLgx8o7YHxoR+1tXSxA9r\n0EWAWJ+Rxw3XnZjO3ACmco6krLcVHmLHvkMx2b8/knI+nItHdmFJ5n5yDkT/BCnByHrfwUqeW7GL\ny4/vHoQSxaZg1+kEj4dLRqXx6pr4vrDwybb9FJRWfOfOcKSfPyLJ9wZ1ICnBw9x1R1zO97BiMedt\nhYd44Yvd3Hxar4gaJx2LWUeieM7ZGnQmJnRqlYyMTOMfy3eFuygBqa7x8uTinVw6qivJifZr6LY2\nzZOYOqILf1mSRVWcr013qLKae+Zt5axBHRu0BIhpugn92lNYWsna3fF5l27nvjKe+Tybm07tZetv\nNlKCx8O0U3oyKyOPez/YyoEYmPW5KZ7+PIsrx3SjT3vraWDii32SjADx3Oc3mC4Y1pmthYeOOB14\npGT92po8WiQlMOWY2Fw4N1JyPhIZmUbzpARufWcze6J4PF1Tsq6u8fL7BTvo1yGFn4zuGsRSxZ5Q\n1OnEBA9XjU3n8U93sqmgceOgotW2wkPc/t4Wrh2XztAurb7zWjScPyJJ7/Yp/PPiY+jdvgU3vrmR\njQWlAR0XazlvLTxIblEFZw7qGO6i/I9YyzpSxXPO1qAzMSM5KYFbJ/Rm+sKd5JdE7gf01buKmf11\nAbec1juiuoTEm8QED/dP7ssJPdpy45ubWJ8f2IegWOH1er8Ze/PrU2ydpnA5tW87Lh/TjfvmbWXm\nspy4uGOckVvCHe9t4RcnpjN5YIdwFycmJCcmcNXYdK48oTv3frCNpxZnxcQarQ3x5td7OHdoJ7vb\na+KSrUNnYs5ra/L4PPMAfzx3YMSd2DNyS3hw/nbumdSHUd3bhLs4xrF05wGmL9zJdSemM2lAfHzA\n/PeqXBbv2M8fzxlIS1vHKuyKyqp4/NNMCg9WctvE3jHbZWxldhGPfpLJHRN7c3yPtuEuTkwqKqvi\nhS92syzrAPdP7sfATi3DXaSQKyqr4nJdx3MXD6V9SrNwF8eYkLF16EzcuHhkF1o3T4y49Xmy9pfx\n4Pzt3Hl6b2vMRZgTe6Xy6NkDeOnLXKYvzORQZXW4ixRS8zYV8v7GQn73/f7WmIsQbVsk8eD3+nHu\n0E7c+s4WXl2dS3WM3a0rLK3ksU8yuW9yX2vMhVDbFkn86uSeXDMunbve38rHW/eGu0gh9/7GQk7q\nnWqNORO3rEEXAeK5z28oJHh8a419uLnwfyYbCFfWldU1/OHjHfzs+G6MTo/9DzLRWKf7dUzhmQsH\nA3D97I1sauTaTm5raNYrs4v4x/Jd/P77/enY0j78BMqNOu3xePjBkE48ff5g1uwu4VdvbmRb4aGQ\nf103eL1e/rgwk3OHdmJE1yNPvhON549IdFrf9jx69gD+tXI3zy3P+Z8LBLGSc0VVDXO+LuDCYZ3D\nXZR6xUrWkS6ec7YGnYlJ7VOacfOpvXjs00xKysM/juC1tfl0bNmMc4ZE3mBt862UZoncclpvfnZ8\nN+5+fyu6Ji+m1nfaWniQRz/J5N7JfenVvkW4i2PqkdYmmYfP6s+UYzpz+3tbePnL3VE/tu6tdXso\nqajm/46zyXfc1K9jCn85fzAbCg5y37xtEfH3MNje31RI/44pDIiDrqXG1MfG0JmY9pfFWZRUVHPn\n6X3CVobdReX86s2NPHPhELq0toVzo0VecQWPfLKD5EQPt03oQ8dW0X03K7+kgmlvbeIXJ6VzWt/Y\nW/swVhWUVvDkoiz2lFZy7xl9SE+Nvob4xoJS7vlgG3+eMpAeUVj+WFBV42XmshxWZhfxwJn96Nku\nNn4OFdU1XK7r+O3kfgzqbA06E/tsDJ2JS1ePS2fznoMs3L4vLF/f6/Xy7NJspo7oYo25KJPWJpk/\nnjOQ4V1bc/2cDXyeWf9yGJHO6/Xy+KeZnDeskzXmokznVsn87nv9OGdIR6bN3cyKrKJwF6lBCkor\neODD7dx0ak9rzIVRUoKH60/qwcUj07jl7c2syomNtQ/f31hI/w4p1pgzcc8adBEgnvv8hloLZymD\nGUuyOVBW5XrW/1yxi8KDlUwd0cXVrxtusVKnExM8/GR0N+47oy/PLs3moY+2s/dgZbiL9R2BZD0r\nI5+K6houHpHmQoliUzjrtMfjYcoxnbl/cl+mf5bJexsLw1aWhqiq8fLg/O2cP6wz43u3C/i4WDl/\nRKKzB3fk7kl9eOSTHTw5d2m4i9MkFdU1vLYmjx9HwRqaVqfdEc85W4POxLyhXVoxsX97/r4sx9Wv\nO3ddAYt2HODhswaQnGi/atFsWNfW/H3qULq3bc51szeweMf+cBcpYGt3l/B6Rj53T+pLYoQt42Ea\nZnjX1vzxnIG8/OVuZi7LobyqJtxFOqLX1uTRpnkiMjK+LmhFulHd2/CncwexbF8zZizJjtrZVD/Y\nWEif9ikM7tzq6DsbE+NsDJ2JCwcrqrnq9fXcMbE3I7uFfsmAdzbs4dXVuTz2g4F0b9s85F/PuOfr\nvBIe/zSTkV3b8MvxPUhOitzGel5xBTfN3cRNp/bihJ6xP7tqvDhQVsXTS7JYs6uES49N44JhnSNu\nYfgd+w5x6ztbmHHBYOtuHqFKyqt4aMEOkhI83HV6n6hawuRQZTU/n7We+yb3ZUgXa9CZ+GFj6Exc\na5mcyPUn9uCpxdlUVof2qvaKrCJe/tIac7FqWFprnr1wCIcqq7n13c0URlgXzFplVTXcO28rF43o\nYo25GJPaIom7J/XlsXMG8PHWfTz2aWZEzYJZ4/Xyp4U7+dnx3awxF8FaN0/iIWf5klve2cye0opw\nFylgs9bmM6Jba2vMGeM4aoNORHaIyFoRWSUiyw/z+vkissZ5/QsRmeT32p0i8rWIZIjIKyLS3Hm+\ng4h8KCKbRGSeiATeuT4GxXOfXzed3CeV5pUlzFqbH7KvUVpRzROLdnLbhN5x3ZiL9Tqd0iyRuyb1\n4YQebblhzgZWZodvoor6sn56cRb9O6YwdXjkrs0UTSKxTvdpn8Jj5wykpLya29/dwq6i8nAXCYBP\ntu7DC/ygkcu0RGLWsWjRokUkJXiYdkpPJvZrz41vbWJrYeSvv5lfUsGb6wr4+Qndw12UgFmddkc8\n5xzIHTovMFFVj1PVsYd5fb6qjlLV44DLgZkAItIHuBoYraojgETgEueYO4APVXUQ8JGzbUxIeTwe\nzu5awRtf5ZNzoCwkX+OfK3YxOr0Nx6WHvlunCS+Px8OPR3fjjol9+NPCnfxtaTYVETKmaUnmfr7O\nK+XGk3tGXFc8E1wtkhL47Zn9OKlXW258cyNvfJUf1jFRhyqreW7FLq4Zl06C1b2o4PF4+NGoNK4d\nl85t727huRW7KK2oDnex6vXPFbuYMrST3f01xk+gXS7rPSuraqnfZmtgj/O4CKgEWopIEtASqJ2V\n4jzgBefxC8AFgRY4Fp1yyinhLkLcOPf0k7nsuK489mlm0D/0fJlTxOc7D3DNuPSgvm80iqc6fWz3\nNjx70RDySir45Zsb2bLH3SvcdbMurahmxpJspp3Sk5Rm0TMmJtJFcp1OTPDww5FpPHneIBbt2M8t\nb28m50B47ta9tiaP4V1bM6Jr60a/RyRnHUvq5jyhX3v+dtEQCg9W8vP/rmP+5r1E2jwLG/JLWbO7\nhB+Niq4Ze61OuyOecw70Dt18EVkpIlcfbgcRuUBE1gPvATcCqOpeYDqwE9gFHFDV+c4haaqa5zzO\nA6LrN9NEtfOHdSalWSKvrs4N2nuWlFcxfeFObj61F22aJwXtfU10SG2RxL1n9OXikV246/2tzFiS\nTUl5VVjK8vzK3YxOb8Oo7naXON6kp7bgj+cMZEK/dkybu4l5m9xd3mB3cTlz1+/hqrHR0xXOfFen\nVsncNqE3v53cj/9m5PPg/O0cjJC7dV6vl78uzeHyMd3sYpUxdQTSoDvZ6U55NnCDiJxadwdVnaOq\nQ4EpwEsAItIfmAb0AboDrUTkssMc68XXaIxb8dzn122LFi0iwePh1tN689a6PazPLz36QQF45vNs\nTuyVypgeNvkExGed9ng8nDmwI//44VAqa2q46vX1roxH8c96fX4pn23fx9Vj7S5xsEVLnU7weLhw\neBce+8EAdG0+Ty3Kosaluywzl+YwdXgXOrdqWle4aMk62h0p5yFdWvHU+YNo2yKJaXM3sTsCxmd+\num0/FdU1nDmwQ7iL0mBWp90RzzkftUGnqrud/wuA2cDhxtHV7vsZkCQinYAxwBJVLVTVKuANYLyz\na56IdAUQkW7AUWep8P8hLVq0KKa2MzIyIqo88bC9ftUybhjfgz9/tpOFnzXt/f7+7ud8mVn4zVXp\nSPj+wr2dkZERUeVxc3vtyqWMYSfXn9SDu9/fyuyPFrty/qiq8fLEZzuZ2L6EtSuXNvr9bDs2tvt2\nSOEv5w9iTWYe97y+4puuc6H6el9kF7Ft7yG6F2+x80eMbCcnJjCGnQxNPsC0uZtYlVMctvIUlFbw\n16XZnNJqL0sWL46IfGw78rbj4fN0fY64Dp2ItAQSVbVYRFoB84AHVHWe3z79gW2q6hWR0cAsVe0v\nIscCLwMnAGXA88ByVZ0hIo8Bhar6qIjcAbRT1XonRrF16EwoeL1ebpq7mXOGduTMgY2bja3wYCXX\nz97Ab8/sx1CbPtnUMX/zXmYuy+E3E3oxtmdqSL/Wa2vyWLO7mN9/v79NhGK+UVpRzR3vbaF/xxSu\nHptOqxCsNVZV4+UXb2zgijHdOLlPXE9aHbPW7Crm4Y938KNR7q97WFldwy1vb2Z8n1QuGdXVta9r\nTCRq7Dp0acBnIrIaWAa8rarzRORaEbnW2WcqkCEiq4AncWayVNXVwIvASmCts+9M5/9HgDNFZBMw\nydk2xlUej4erxnbnxS9yGzU7odfrZfrCTM4Z0skac+awJg/swP2T+/Lnz7J4eVVuyLq+rdlVzH8z\n8vmVzWpp6miVnMgfzupPZbWXK2et48PNwR9X99qaPNJaJzO+d2gvWpjwGdW9DU+cN4gPNu1l+sKd\nrs7oO2ttPm1bJPGjkTbdgjH1OeIdukgR63foFi1aFNcz87jpcFnfN28ro7q1YeqILg16r7fX7+GD\nTYX8ecogkhLsQ7Q/q9PfVVhaye8+2k7bFoncclpvUlskBe29/zt/Ca/ltuGuSX04ziZCCZlYqNOb\n9hzk0Y93cExaK24Y35MWSYFOdF2/7XsPcdu7W5hxweCgTSMfC1lHg8bkfKiymj8t3ElOUTl3T+pL\nempo11vdXVTOr97cyIwLhpDWJnqXKbA67Y54yLmxd+iMiXlXjOnOa2vyKCoLfFbC3OJyXvhiN785\nrZc15sxRdWzVjMfPGUCP1BZcN3sDq3YVB+V9c4vLeTW7Ob8c38Mac+aoBnVqydMXDKaqxsv1szew\nqaBpk/bUeL1MX7iTK8d0szXB4kRKs0TumtSHswZ3ZNrcTSzYsjdkX8vr9fKXJVnIyLSobswZ4wa7\nQ2cMMGNJFkXl1Vw7Lp0OLZsdcd8ar5c73tvC8elto24tHBN+y7MO8NTiLIZ2bsXV49Ib/UG4rKqG\nX7+5ke8P7shFwxt2d9mYj7fu45nPs/nJ6K6cO7RToxYBX7BlL3O+LuDJ8wZZV984tLXwIH9YsIPU\nlCR+Orobxwb5otLC7ft46ctcnr1wiF04NcZR3x06a9AZg68bySOfZPJVbgnNExMY2Kklvdu3oEdq\nc8b3TqW139pyb60r4MPNe3liyiAS7Y+MaYSyqhp0TR5vrStg6oguTB3RheTEwDtMeL1eHl+4E6/X\ny20TetuHadMoWfvLeOzTTFokJfDj47oyslvrgOtSSXkV183eyC2n9Qr6B3kTPaprvCzcvo+/L9vF\nOUM7cemxaY26OOD/flsLD7F05wHeWlfA/Wf2a9Ii9cbEGutyGcGONA2pCa76sk5plsgDZ/bjvz8e\nwfQpAzljQHuSEz3M37KXRz/JpLrGi9fr5fWMfF5ZncutE3pbY+4IrE4fWYukBH56fDf+cv5g1ueX\ncsPsjWzaE3j3t/c3FrJ5z0FuPLkni/2m8DahE4t1ume7FjwxZRAT+rXnqcVZ3DR3M5sDqIdep6vl\nib1SQ9KYi8WsI1Ewck5M8HB6/w785fzBLM86wEMfNW4h8nmbCrnzvS1MfWktjy/MpLi8mj9PGRQz\njTmr0+6I55yDNzLfmBjg8Xjo1qY53dr4BnqXV9XwwPxtPDB/Gx485JVU8OSUwdaf3wRFt7bNeeDM\nfizYuo97P9jKoE4t+dGoNIYf4UPMxoJS/rlyN9PPGUhKs+BPQW/iS2KCh3OHduLswR2Zt6mQez7Y\nyvjeqVwxpjtt65m8Z87XBRSUVnLnpD7uFtZELN844YHMWJLN9XM28IMhnTg+vQ19O6SQ4PFQUl7F\n8qwi8koqqO0YdqiqhuZJCeQWlbM+v5Sfj+3Onaf3qbfeGWPqZ10ujTmKyuoa/rVyNx1SkjhvWOcG\ndY0zJlDlVTXM37KXV1fnMrZHKleP6/4/DbYDZVXcMGcDvzixB6fYel8mBIrLq3jhi90s21nEg9/r\nR98OKd95fUN+KffO28ZT5w/65sKXMf5W7yrms+37+TKnmJKKaponeSgur2ZUt9b0btfim269Kc0S\nKKuqoVmCh/OO6WwNOWMCYGPojDEmCpRWVDPj82zW5ZVy24TeHJPmW+OwqsbLPR9sZUDHFK4amx7m\nUppYt2DLXp5dmsNNp/ZkfG/fxYPi8iqun72Ra09MtwsKJiD5JRVUe710atmMZnYx1JgmszF0ESye\n+/y6zbJ2h+XceK2SE7ltQm+uOqE7D8zfxr9W7OJQZTV//mwnSQkerhjT/Tv7W9buiLecJw3owO++\n14+nl2Qzc1kOFVU1PP5pJuN7p4a8MRdvWYeLGzl3aZ1MtzbN474xZ3XaHfGcc3z/hhljTIQ6pW87\nnr1wCJn7y7jwxbXsP1TF3ZP62GQ8xjVDurTi2QuHkH2gjB+98hXlVTVcNbb70Q80xhjjKutyaYwx\nEa7cmTzAmHDwer3sKqogrU2yrQdmjDFhVF+XSxuBaowxEc4acyacPB4P6ak2AYoxxkQq+5QQAeK5\nz6/bLGt3WM7usazdYTm7x7J2h+XsHsvaHfGcszXojDHGGGOMMSZK2Rg6Y4wxxhhjjIlwtmyBMcYY\nY4wxxsQYa9BFgHju8+s2y9odlrN7LGt3WM7usazdYTm7x7J2RzznbA06Y4wxxhhjjIlSNobOGGOM\nMcYYYyKcjaEzxhhjjDHGmBhz1IXFRWQHUARUA5WqOrbO6+cDDwI1zr9bVXWBiAwG/uO3az/gl/cM\nPwAAEVFJREFUXlV9SkTGAk8DzYAq4HpVXRGE7ycqLVq0iFNOOSXcxYgLlrU7LGf3WNbusJzdY1m7\nw3J2j2XtjnjO+agNOsALTFTVvfW8Pl9V3wQQkRHAbGCAqm4EjnOeTwBynNcAHsPXuPtARM52tk9v\n/LdhjDHGGGOMMfEn0C6X/9NXs5aqlvpttgb2HGa3ycBWVc1ytncDqc7jdvgae3ErXq8mhINl7Q7L\n2T2WtTssZ/dY1u6wnN1jWbsjnnMO9A7dfBGpBv6mqn+vu4OIXAA8DHQDvneY97gEeMVv+w5gkYj8\nEV+j8qSGFtwYY4wxxhhj4l0gd+hOVtXjgLOBG0Tk1Lo7qOocVR0KTAFe8n9NRJKd52f5Pf0ccKOq\n9gJuAv7ZyPLHhHheN8NtlrU7LGf3WNbusJzdY1m7w3J2j2XtjnjOuUHLFojI/UCJqk4/wj5bgbGq\nWuhsnw9cp6pn+e1TpKptncceYL+qph72DfEtWxBwIY0xxhhjjDEmBh1u2YIjdrkUkZZAoqoWi0gr\nfN0pH6izT39gm6p6RWQ0QG1jznEp8Gqdt94iIhNU9VNgErCpoQU3xhhjjDHGmHh3tDF0acBsEand\n99+qOk9ErgVQ1b8BU4GfikglUIJvvBwATiNwMnB1nfe9BpghIs2BQ862McYYY4wxxpgGaFCXS2OM\nMcYYY4wxkSPQZQuMMcYYY4wxxkQYa9AZY4wxxhhjTJSyBp0xxhhjjDHGRClr0LnAWYvPuMCydofl\n7B7L2h2Ws3ssa3dYzu6xrN1hOdfPGnQhJiLTgOUi8oCInOs8Z8swhIBl7Q7L2T2WtTssZ/dY1u6w\nnN1jWbvDcj4ya9CFkIicgW8dviuAjcADIjLOWbPPsg8iy9odlrN7LGt3WM7usazdYTm7x7J2h+V8\ndBZCkIlIM7/NTsC7qrpKVV8BXgT+CqCqNeEoXyyxrN1hObvHsnaH5ewey9odlrN7LGt3WM4NYw26\nIBGRZiLyJ+Bx50oCQBUwsXYfVX0SaCYiVzjH2K3iRrCs3WE5u8eydofl7B7L2h2Ws3ssa3dYzo1j\nDbogcG73zsB3BeFL4E4RuVZVXwe6iMhlfrvfA/wQQFVtVfcGsqzdYTm7x7J2h+XsHsvaHZazeyxr\nd1jOjWcNuuBIBUYC16rqi8B04FgRmQDcAPxBRJo7++4C1otIovX7bRTL2h2Ws3ssa3dYzu6xrN1h\nObvHsnaH5dxIcR9AY9Xe3hWRBFXdB2TiG6wJsBhYCVyiqp8A84CnRORi4HagtapWW7/fhrGsQ8vq\ntPss69CyOu0+yzq0rE67z7IOLavTweHxeuP+LmWDiMgtwFuqutmpfDXOlYFLgDOAO1U1X0ROAH4K\n/AnYD5yCr4J+par3hav80UREPLW30S3r0LE67R6r0+6wOu0eq9PusDrtHqvT7rA6HVzWoAuQiPwI\nuAnoCzygqs84z58LbAEOAjcCBar6qPPa58BNqrrU2W6mqpXhKH80EZEfAz8HVgHLVPU153nLOois\nTrvH6rQ7rE67x+q0O6xOu8fqtDusTodGUrgLEMmc28DtgL8BbfHd3j0bX2Wr1Rrw4OvL+zbwexHZ\nBGQ4+1XV7miVr35O1i2Bh4DRwH3AIOBiEdmuqsvx/Qws6yawOu0eq9PucK7opmJ12hUi0gqr0yFl\n52l3iUhL4PdYnQ4pEWkHzMTqdEjYHbp6iEiSqlY5jyc6fXcRkV8DU1X1tHqOOw+4EBgPPKGqz7pU\n5KglIi1Utcx5/HNgtqruFZE04HfAy6q68DDHWdYNUCfnSaq6wHlsdTrIRKSNqhY7j61Oh0idnE9X\n1Y+dx1ang6y2S5Tz2Op0iNTJ2eq0S0TkSmCO1enQsjodOjYpymGIyB3ACyJyuYi09WvMJQAfAwUi\n0u8wxyWo6lvAL4ChVvmOTkSmAitEZIrz1CznhJqkqnlAf3xXbOoeZ1k3QN2c/RpzVqeDTESmARki\nMs556lWr08FXN2e/DwlWp4NMRO4Hnna6SgG8AOy3Oh1cfjkL+Oq0iHisTgefiNwgIsf5PfUfO08H\nn3/OIpJo5+nQsS6XfkRkFL4/VOuBfwOPAduAhU5FrBaRJHzdqPbXOfZhfLeFX1HVcndLHn3k20HH\nLYFS4DIRmaeqRQCqWiUiXYBKYG2dYx8DVmNZH9URci63Oh1cIjIUeB1YBpylqhsAVPWg87/V6SCo\nL2fntdqB9Vang0RE7sF3hXwGcIuI9ABeUtV8oMbqdHAcJueewIuqWgB4rU4Hh4j0wvc5byi+z3qn\nOy8dAjtPB8vhclbVauc1j52ng8/u0H1XLnCvql6qqm8DnwHtAWoroqp+CfTANwNP7VUGgIdV9RX3\nixyd9NtFIHsBr+KbpvZX4Bvs6ryWBlSo6j4RGSYi5zjPP2RZB+ZIOeP8/ludDpo9QBfgblXdICI9\nnQ8G/rpgdbqp6s25tqua1engcD5wnQrc6lwtvw/fefkSv93sPN1ER8j50tp9rE4HzV7gP/jGyZU5\n3Yfhu5+H7TzddIfN2bmQ7AWr08FmDTqHc2U3T1XnikiyiDwPXAxcLSLXiEhXv91fA4bDdz5AFLle\n6Cjm94u7GygHPgFOEpHBQCfntWOA5s6VyxfxXcmxrBvgKDl38NvV6nQTiG/GrQLgCeBFEZkOzHIe\nX+V3/hiO1elGCyDnNL/drU43gXw7jvxrvm1YLAaWA8NFZJjznJ2nmyCAnI/x293qdBM4n/NK8N35\nLAKeAW4QkRS/3irgu6tkdbqRAsg5QUQSnd2tTgdJ3DboRKSF3+NE9VuUUFUrgM+BzsBT+P5gnep3\neEt8t91NAOpmDd/+4gInAh+r6ntAR2Ah32Y93nncCpigqrNcK3QUakTOE/wOtzrdAIc5f1QCqOpD\n+O7qNwdOAp4FRgK1g77HYXU6YI3I2ep0I4lIqt/jRKeRAfA+kC4iw5znMoB9QO1FipOwOh2wRuTc\nze9wq9MNcJisaxsMh5yn38bXkH7Qeb72ZzEe3znb6nQAGpFzTW2vN3wZW50Ogrib5VJEvg9MA7KB\nz1T1Ref5cUA7Vf3gMMc8DyxS1X84282tX+/RHSXrjqr6rohch+8DwWDnsFLgZlVdLSJnATmqmhGG\n4keNJuQ8TVXXOvtanQ7AUbLurKpvi0gXZ3xR7TEvAktV9Rmr04FpQs6LVfVvzrbV6QCIyJnAXUAW\nvoV6H3OeHwekAF8AtwApqnq789qbwGuq+orzs9pldfrImpDzq6r6H2fb6nQAjpD1WHyf8+b57Xsc\n8BwwCV/voGx8F9721f59NIfXhJw7AF5V3S5+s2+bpomLSVHEt6ZLIr6TpeDrn54KnCsiRao6B2iD\nbxBs3WM74LsSnFP7nJ1Q69eArGt/gZvj60P9qKq+ISK/AX4GrFbV913/BqJEkHK+HLgZrE4fSQOy\nrh1U79/I6Ijvj1e285rV6XoEKWc7TwfAyToJ3+//hfgmANuPr1vUaGdsSxugWlWLReRt4AERuRn4\nF9AMKAY43EVQ4xPMnMHq9JE0IOsq/+NUdZWIrMQ3NvcL4FJV/dTVwkeRIOW8ErjMed4ac0ES810u\nnTFECc6t9Cx8v6zvAHPx/fFPdnb9SL+dyr2ZiHQVkT8DC/BdXX8vDMWPKo3JGt86L5NU9Q1n+0VV\nvcnVgkeZIOZ8s6sFj0INzPoj55gkEWnrd/5Yor6JDkw9gpjz22EoflTxy7oSp4u7c17YDtQAW5xu\nU/PVmWJcVVcCd+Pr1vop8IWqzg3PdxAdgpjzO+H5DqJHA7L2/5yX6Pz/a+AHwD2qOk5Vt4Xnu4h8\nQcz5RFXdGp7vInbFdINOfAtF5uBbIBJgDr4K10x9i9H2wLcyvf9sgOC7KrYX2AicqaoPu1fq6NSE\nrGsXuk52XsvH1Mtydk8Tsm6uvkHd64HJqvoHF4sddSxn9/hl/aDz1HJVrRSRk4HZ+NbeegZ4uM5x\nbVV1NXANME5V73Wx2FHHcnZPY7PG180VYB1wrKo+4kZ5o5XlHPlidgydiLTGt5bcx/i68F2sqlv8\nXk/GN6Xq/f59/0XkV0Arq3SBa0LWvwRaW9aBsZzd08TzR2u7CBQYy9k9R8pafLPe1qjqZuexApep\n6lcicgPQ1rIOjOXsniZm3U5Vfx+uskcTyzk6xOwdOvVNmforVX0C+ADnqoLT/xd84+JaqmqGiKSL\nyA+d5/9hH3wbpglZP2dZB85ydk8Tzx/2gSxAlrN76svaeW2jqm52NrcBK4Dan8E/LevAWc7uaWLW\n1sgIkOUcHWK2QQegqjudh08AA0Xk+35ddvoC7URkGvAOzhTM+u00q6YBLGt3WM7usazdYTm753BZ\nw7fjXBy3Ab34diIfy7qBLGf3WNbusJwjX0w36Gqpai7wD3yDjWudCIwBhgDnqerT4ShbrLGs3WE5\nu8eydofl7J66Watvsd9LRORzYBhwharuC2cZY4Hl7B7L2h2Wc+SK2TF0/kTEo6peEXkdyAUK8Q3u\nXK+qC8NbuthiWbvDcnaPZe0Oy9k9dbLeDRQBXwGb1DfTogkCy9k9lrU7LOfIFRcNOgARaYmv7+9Q\n4Heq+mSYixSzLGt3WM7usazdYTm7x7J2h+XsHsvaHZZzZIqLhcUd1wFf4pve2hbnDC3L2h2Ws3ss\na3dYzu6xrN1hObvHsnaH5RyB4qlB92dVrQl3IeKEZe0Oy9k9lrU7LGf3WNbusJzdY1m7w3KOQHHT\n5dIYY4wxxhhjYk1czHJpjDHGGGOMMbHIGnTGGGOMMcYYE6WsQWeMMcYYY4wxUcoadMYYY4wxxhgT\npaxBZ4wxJiqJyA4ROSPEX6NYRPoE8f1qRKRfsN7PGGOMiadlC4wxxsQWr/MvZFS1Te1jEXkeyFLV\ne0P5NY0xxpiGsDt0xhhjjDHGGBOl7A6dMcaYqCYiycBjwMXOUwrcrqoVIjIReBn4E3A7UA3cparP\nO8d2BJ4HTgM2AvOACap6qvN6DTAQOAP4P8ArItOABap6vvP6AFXd5uz/PH538UTkVuAmoAa4r065\nmwO/d8rdHJgN3KSqZUGMxxhjTIyzO3TGGGOimQe4BxgLjHL+jXWeq5UGtAW6Az8HZohIqvPaDKDY\n2ednwE/5326cXlWdCfwbeFRV26jq+fWU55tuoCJyFnALMBkY5Pzv7xFggFPmAUA6dRp9xhhjzNFY\ng84YY0y0+z/gQVXdo6p7gAeAn/i9Xum8Xq2q7wElwGARSQQuAu5X1TJVXQ+8gK+RWJ8jvVaXAP9U\n1XWqehC4/5sXRDzA1cDNqrpfVUuAh4FLGvD+xhhjjHW5NMYYE/W6A5l+2zud52oVqmqN3/ZBoDXQ\nGd/fwSy/17KDWK5uwIo65arVGWgJfCEitc95sAutxhhjGsgadMYYY6LdLqAPsN7Z7uU8dzQFQBXQ\nE9jsPNfzCPsfbkbNg/gaZrW68W0DcbdTllr+j/cAh4BjVHV3AGU1xhhjDsuuBBpjjIl2rwL3iEgn\nEemEbxzaS0c7SFWrgTeA34pIiogMwddVs76lEPKAumvIrQYuE5FEZ8zcaf5fArhcRIaKSEv8ulw6\ndwz/DjwhIp0BRCRdRL4XwPdrjDHGfMMadMYYY6KZF3gIWAmsdf6tdJ7z36c+vwRSgVx84+deBSrq\nOfY54BgR2ScibzjP/RqYAuzDN5Zvdu3Oqvo+8ASwANgEfFTn/W4HtgBLReQA8CG+yVOMMcaYgHm8\n3pCuyWqMMcZEDRF5FOiiqleEuyzGGGNMIGwMnTHGmLglIoPxrQGXAZwAXIlvaQNjjDEmKliDzhhj\nTDxrg6+bZXd8Y+T+qKpvhbdIxhhjTOCsy6UxxhhjjDHGRCmbFMUYY4wxxhhjopQ16IwxxhhjjDEm\nSlmDzhhjjDHGGGOilDXojDHGGGOMMSZKWYPOGGOMMcYYY6KUNeiMMcYYY4wxJkr9P+fwhouXdfJ4\nAAAAAElFTkSuQmCC\n",
       "text": [
        "<matplotlib.figure.Figure at 0x10afec850>"
       ]
      },
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAA3QAAAFLCAYAAACeI87qAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nrkJggg==\n",
       "text": [
        "<matplotlib.figure.Figure at 0x10ab0f4d0>"
       ]
      }
     ],
     "prompt_number": 9
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "df.lon.plot(x='time', figsize=(15,5))\n",
      "df.lat.plot(x='time', secondary_y=True, style='g');"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAA5YAAAFACAYAAADH8+NlAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nFCFVZnJRAAAAAElFTkSuQmCC\n",
       "text": [
        "<matplotlib.figure.Figure at 0x10e3fdf10>"
       ]
      }
     ],
     "prompt_number": 10
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "df.plot(x='lon', y='lat', figsize=(15,15), legend=False);"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAA3QAAAOACAYAAABykzG0AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nAFbq/wOHcc6bq+6K/QAAAABJRU5ErkJggg==\n",
       "text": [
        "<matplotlib.figure.Figure at 0x10afec790>"
       ]
      }
     ],
     "prompt_number": 11
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "plt.plot(df.lon.values, df.lat.values)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "pyout",
       "prompt_number": 12,
       "text": [
        "[<matplotlib.lines.Line2D at 0x10fa2ab90>]"
       ]
      },
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAYwAAAEICAYAAABMGMOEAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
       "text": [
        "<matplotlib.figure.Figure at 0x10af3e890>"
       ]
      }
     ],
     "prompt_number": 12
    },
    {
     "cell_type": "heading",
     "level": 2,
     "metadata": {},
     "source": [
      "embedding that info in a map"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "from IPython.display import IFrame\n",
      "from IPython.core.display import display\n",
      "\n",
      "# Google Maps URL template for an iframe\n",
      "lat, lon, zoom = df.lat.values.mean(), df.lon.values.mean(), 14\n",
      "google_maps_url = \"http://maps.google.com/maps?q={0}+{1}&\" + \\\n",
      "  \"ie=UTF8&t=h&z={2}&{0},{1}&output=embed\".format(lat, lon, zoom)\n",
      "\n",
      "display(IFrame(google_maps_url, '425px', '350px'))"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "        <iframe\n",
        "            width=\"425px\"\n",
        "            height=350px\"\n",
        "            src=\"http://maps.google.com/maps?q={0}+{1}&ie=UTF8&t=h&z=14&43.2614095225,5.38417487021&output=embed\"\n",
        "            frameborder=\"0\"\n",
        "            allowfullscreen\n",
        "        ></iframe>\n",
        "        "
       ],
       "metadata": {},
       "output_type": "display_data",
       "text": [
        "<IPython.lib.display.IFrame at 0x10ab33a90>"
       ]
      }
     ],
     "prompt_number": 13
    },
    {
     "cell_type": "raw",
     "metadata": {},
     "source": [
      "!pip install folium"
     ]
    },
    {
     "cell_type": "raw",
     "metadata": {},
     "source": [
      "import folium\n",
      "map_osm = folium.Map(location=[45.5236, -122.6750])\n",
      "map_osm.create_map(path='/tmp/osm.html')"
     ]
    },
    {
     "cell_type": "raw",
     "metadata": {},
     "source": [
      "display(IFrame('file://tmp/osm.html', '425px', '350px'))"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "!pip install smopy"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "Requirement already satisfied (use --upgrade to upgrade): smopy in /usr/local/lib/python2.7/site-packages\r\n",
        "Cleaning up...\r\n"
       ]
      }
     ],
     "prompt_number": 14
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "import smopy\n",
      "print df.lat.values.min(), df.lon.values.min(), df.lat.values.max(), df.lon.values.max()\n",
      "map = smopy.Map((df.lat.values.min(), df.lon.values.min(), df.lat.values.max(), df.lon.values.max()), z=13)\n",
      "map.show_ipython()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "43.257541 5.379072 43.265526 5.39451\n"
       ]
      },
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAQAAAAIACAIAAADi+CWsAAEAAElEQVR4nKz9eZAjaXYfCD53+O2A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\nVer/H7KOpNIAfa8nAAAAAElFTkSuQmCC\n"
      }
     ],
     "prompt_number": 15
    },
    {
     "cell_type": "raw",
     "metadata": {},
     "source": [
      "smopy.Map?"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "ax = map.show_mpl()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "ename": "AssertionError",
       "evalue": "",
       "output_type": "pyerr",
       "traceback": [
        "\u001b[0;31m---------------------------------------------------------------------------\u001b[0m\n\u001b[0;31mAssertionError\u001b[0m                            Traceback (most recent call last)",
        "\u001b[0;32m<ipython-input-16-e20009c91642>\u001b[0m in \u001b[0;36m<module>\u001b[0;34m()\u001b[0m\n\u001b[0;32m----> 1\u001b[0;31m \u001b[0max\u001b[0m \u001b[0;34m=\u001b[0m \u001b[0mmap\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0mshow_mpl\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[0m",
        "\u001b[0;32m/usr/local/lib/python2.7/site-packages/smopy.pyc\u001b[0m in \u001b[0;36mshow_mpl\u001b[0;34m(self, ax, figsize, dpi)\u001b[0m\n\u001b[1;32m    267\u001b[0m             \u001b[0mplt\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0mylim\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0mself\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0mh\u001b[0m\u001b[0;34m,\u001b[0m \u001b[0;36m0\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m    268\u001b[0m             \u001b[0mplt\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0maxis\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0;34m'off'\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m;\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[0;32m--> 269\u001b[0;31m             \u001b[0mplt\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0mtight_layout\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m;\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[0m\u001b[1;32m    270\u001b[0m         \u001b[0max\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0mimshow\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0mself\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0mimg\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m;\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m    271\u001b[0m         \u001b[0;32mreturn\u001b[0m \u001b[0max\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n",
        "\u001b[0;32m/usr/local/lib/python2.7/site-packages/matplotlib/pyplot.pyc\u001b[0m in \u001b[0;36mtight_layout\u001b[0;34m(pad, h_pad, w_pad, rect)\u001b[0m\n\u001b[1;32m   1286\u001b[0m \u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m   1287\u001b[0m     \u001b[0mfig\u001b[0m \u001b[0;34m=\u001b[0m \u001b[0mgcf\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[0;32m-> 1288\u001b[0;31m     \u001b[0mfig\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0mtight_layout\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0mpad\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0mpad\u001b[0m\u001b[0;34m,\u001b[0m \u001b[0mh_pad\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0mh_pad\u001b[0m\u001b[0;34m,\u001b[0m \u001b[0mw_pad\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0mw_pad\u001b[0m\u001b[0;34m,\u001b[0m \u001b[0mrect\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0mrect\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[0m\u001b[1;32m   1289\u001b[0m     \u001b[0mdraw_if_interactive\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m   1290\u001b[0m \u001b[0;34m\u001b[0m\u001b[0m\n",
        "\u001b[0;32m/usr/local/lib/python2.7/site-packages/matplotlib/figure.pyc\u001b[0m in \u001b[0;36mtight_layout\u001b[0;34m(self, renderer, pad, h_pad, w_pad, rect)\u001b[0m\n\u001b[1;32m   1652\u001b[0m                                          \u001b[0mrenderer\u001b[0m\u001b[0;34m,\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m   1653\u001b[0m                                          \u001b[0mpad\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0mpad\u001b[0m\u001b[0;34m,\u001b[0m \u001b[0mh_pad\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0mh_pad\u001b[0m\u001b[0;34m,\u001b[0m \u001b[0mw_pad\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0mw_pad\u001b[0m\u001b[0;34m,\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[0;32m-> 1654\u001b[0;31m                                          rect=rect)\n\u001b[0m\u001b[1;32m   1655\u001b[0m \u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m   1656\u001b[0m         \u001b[0mself\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0msubplots_adjust\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0;34m**\u001b[0m\u001b[0mkwargs\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n",
        "\u001b[0;32m/usr/local/lib/python2.7/site-packages/matplotlib/tight_layout.pyc\u001b[0m in \u001b[0;36mget_tight_layout_figure\u001b[0;34m(fig, axes_list, subplotspec_list, renderer, pad, h_pad, w_pad, rect)\u001b[0m\n\u001b[1;32m    350\u001b[0m                                      \u001b[0msubplot_list\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0msubplot_list\u001b[0m\u001b[0;34m,\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m    351\u001b[0m                                      \u001b[0max_bbox_list\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0max_bbox_list\u001b[0m\u001b[0;34m,\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[0;32m--> 352\u001b[0;31m                                      pad=pad, h_pad=h_pad, w_pad=w_pad)\n\u001b[0m\u001b[1;32m    353\u001b[0m \u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m    354\u001b[0m     \u001b[0;32mif\u001b[0m \u001b[0mrect\u001b[0m \u001b[0;32mis\u001b[0m \u001b[0;32mnot\u001b[0m \u001b[0mNone\u001b[0m\u001b[0;34m:\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n",
        "\u001b[0;32m/usr/local/lib/python2.7/site-packages/matplotlib/tight_layout.pyc\u001b[0m in \u001b[0;36mauto_adjust_subplotpars\u001b[0;34m(fig, renderer, nrows_ncols, num1num2_list, subplot_list, ax_bbox_list, pad, h_pad, w_pad, rect)\u001b[0m\n\u001b[1;32m    129\u001b[0m         \u001b[0mtight_bbox_raw\u001b[0m \u001b[0;34m=\u001b[0m \u001b[0munion\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0;34m[\u001b[0m\u001b[0max\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0mget_tightbbox\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0mrenderer\u001b[0m\u001b[0;34m)\u001b[0m \u001b[0;32mfor\u001b[0m \u001b[0max\u001b[0m \u001b[0;32min\u001b[0m \u001b[0msubplots\u001b[0m\u001b[0;34m]\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m    130\u001b[0m         tight_bbox = TransformedBbox(tight_bbox_raw,\n\u001b[0;32m--> 131\u001b[0;31m                                      fig.transFigure.inverted())\n\u001b[0m\u001b[1;32m    132\u001b[0m \u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m    133\u001b[0m         \u001b[0mrow1\u001b[0m\u001b[0;34m,\u001b[0m \u001b[0mcol1\u001b[0m \u001b[0;34m=\u001b[0m \u001b[0mdivmod\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0mnum1\u001b[0m\u001b[0;34m,\u001b[0m \u001b[0mcols\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n",
        "\u001b[0;32m/usr/local/lib/python2.7/site-packages/matplotlib/matplotlib/transforms.pyc\u001b[0m in \u001b[0;36m__init__\u001b[0;34m(self, bbox, transform, **kwargs)\u001b[0m\n\u001b[1;32m   1055\u001b[0m         \u001b[0;34m*\u001b[0m\u001b[0mtransform\u001b[0m\u001b[0;34m*\u001b[0m\u001b[0;34m:\u001b[0m \u001b[0ma\u001b[0m \u001b[0;36m2\u001b[0m\u001b[0mD\u001b[0m \u001b[0;34m:\u001b[0m\u001b[0;32mclass\u001b[0m\u001b[0;34m:\u001b[0m\u001b[0;34m`\u001b[0m\u001b[0mTransform\u001b[0m\u001b[0;34m`\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m   1056\u001b[0m         \"\"\"\n\u001b[0;32m-> 1057\u001b[0;31m         \u001b[0;32massert\u001b[0m \u001b[0mbbox\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0mis_bbox\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[0m\u001b[1;32m   1058\u001b[0m         \u001b[0;32massert\u001b[0m \u001b[0misinstance\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0mtransform\u001b[0m\u001b[0;34m,\u001b[0m \u001b[0mTransform\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m   1059\u001b[0m         \u001b[0;32massert\u001b[0m \u001b[0mtransform\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0minput_dims\u001b[0m \u001b[0;34m==\u001b[0m \u001b[0;36m2\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n",
        "\u001b[0;31mAssertionError\u001b[0m: "
       ]
      },
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAV0AAADtCAYAAAAcNaZ2AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz\nAAALEgAACxIB0t1+/AAAAz1JREFUeJzt1DEBACAMwDDAv+fhohwkCnp1z8wCoHFeBwD8xHQBQqYL\nEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJd\ngJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDp\nAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRM\nFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBk\nugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh\n0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUI\nmS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5A\nyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQB\nQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYL\nEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJd\ngJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDp\nAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRM\nFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBk\nugAh0wUImS5AyHQBQqYLEDJdgJDpAoRMFyBkugAh0wUImS5AyHQBQqYLEDJdgNAFT1UE1685r10A\nAAAASUVORK5CYII=\n",
       "text": [
        "<matplotlib.figure.Figure at 0x10fa4b190>"
       ]
      }
     ],
     "prompt_number": 16
    },
    {
     "cell_type": "raw",
     "metadata": {},
     "source": [
      "map.show_mpl?"
     ]
    },
    {
     "cell_type": "raw",
     "metadata": {},
     "source": [
      "map.show_ipython?"
     ]
    },
    {
     "cell_type": "raw",
     "metadata": {},
     "source": [
      "%load_ext pep8_magic\n",
      "http://nbviewer.ipython.org/github/rossant/smopy/blob/master/examples/example1.ipynb"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "!pip install git+https://github.com/rossant/smopy.git"
     ],
     "language": "python",
     "metadata": {},
     "outputs": []
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "to determine the zoopm, use http://wiki.openstreetmap.org/wiki/Zoom_levels"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "x, y = map.to_pixels(48.86151, 2.33474)\n",
      "ax = map.show_mpl(figsize=(8, 6))\n",
      "ax.plot(x, y, 'or', ms=10, mew=2);"
     ],
     "language": "python",
     "metadata": {},
     "outputs": []
    },
    {
     "cell_type": "raw",
     "metadata": {},
     "source": [
      "nbviewer.ipython.org/github/vins31/gis-experiments/blob/master/Altitude roads.ipynb\n"
     ]
    }
   ],
   "metadata": {}
  }
 ]
}